@@ -357,16 +357,9 @@ Complex erfc(const Complex &in);
 
 // Define real & complex conjugation for non-complex types
 // and put comparisons into std namespace.
-// The new C++11 standard library already defines real and imag.
 namespace std { 
   inline float  conj(float  x) { return x; }
   inline double conj(double x) { return x; }
-#if !(defined(AIPS_CXX11) || (defined(__APPLE_CC__) && __APPLE_CC__ > 5621))
-  inline float  real(float  x) { return x; }
-  inline double real(double x) { return x; }
-  inline float  imag(float   ) { return 0; }
-  inline double imag(double  ) { return 0; }
-#endif  
   using casacore::operator>;
   using casacore::operator>=;
   using casacore::operator<;
