@@ -1,5 +1,5 @@
 //# UnitMap.cc: defines the UnitMap class containing standard unit definitions
-//# Copyright (C) 1994-2002,2007
+//# Copyright (C) 1994-2002,2007,2016
 //# Associated Universities, Inc. Washington DC, USA.
 //#
 //# This library is free software; you can redistribute it and/or modify it
@@ -34,18 +34,37 @@
 
 namespace casacore { //# NAMESPACE CASACORE - BEGIN
 
+// static initialization
+unsigned long unit_map_initialize_::count = 0;
+
 // Initialize statics.
 Mutex UnitMap::fitsMutex;
 
 
 void UnitMap::initUM() {
-  // Mutex for map initializations.
-  static Mutex umMutex;
+  // Recursive mutex for recursive map inits. Always locks in pre-C++11 builds.
+  // Need C++11 or later to implement double checked locking correctly.
+#if defined(USE_THREADS)
+  static std::recursive_mutex umMutex;
+  static std::atomic<int> initialized;
+  // Cannot use std::call_once() (recursion), so distinguish between init states.
+  const int INITING = 1;
+  const int INITIALIZED = 2;
+
+  int init = initialized.load(std::memory_order_acquire);
+  if (init < INITIALIZED) {
+    std::lock_guard<std::recursive_mutex> lock(umMutex);
+    init = initialized.load(std::memory_order_relaxed);
+    if (init < INITING) {
+      // Set initialized, because the initUMSI.() and initUMCust.() calls below
+      // may call clearCache(), which calls initUM().
+      // Note: lacks exception safety. Was already broken (new map<> below).
+      initialized.store(INITING, std::memory_order_relaxed);
+#else
   static Bool needInit = True;
   if (needInit) {
-    ScopedMutexLock lock(umMutex);
-    if (needInit) {
-      // Initialise lists
+#endif
+      // Initialize lists
       UnitMap::mapPref = 
         new map<String, UnitName>;
       UnitMap::mapDef =
@@ -59,12 +78,13 @@ void UnitMap::initUM() {
       UnitMap::mapCache =
         new map<String, UnitVal>;
       UnitMap::doneFITS = False;
+#if !defined(USE_THREADS)
+      needInit = False;
+#endif
       // Define the map
       // Known prefixes
       UnitMap::initUMPrefix();
-      // Set needInit here, because the following functions may use
-      // clearCache, which calls initUM.
-      needInit = False;
+
       // Defining SI units
       UnitMap::initUMSI1();
       UnitMap::initUMSI2();
@@ -74,7 +94,10 @@ void UnitMap::initUM() {
       UnitMap::initUMCust3();
       //# Start with clean cache
       UnitMap::mapCache->clear();
+#if defined(USE_THREADS)
+      initialized.store(INITIALIZED, std::memory_order_release);
     }
+#endif
   }
 }
 
@@ -132,7 +155,6 @@ Bool UnitMap::getUnit(const String& s, UnitName &name) {
 void UnitMap::putCache(const String& s, const UnitVal& val) {
   UnitMap::initUM();
   if (! s.empty()) {
-    if (mapCache->size() > 200) clearCache();
     mapCache->insert(map<String, UnitVal>::value_type(s,val));
   }
 }
@@ -226,33 +248,34 @@ Bool UnitMap::getNameFITS(const UnitName *&name, uInt which) {
 
 void UnitMap::addFITS() {
   UnitMap::initUM();
+
+  // Could be optimized using C++11 std::call_once(), but infrequently called.
+  // If to be optimized, do note clearFITS() below (but not used atm).
+  // Double checked locking is unsafe pre-C++11!
+  ScopedMutexLock lock(UnitMap::fitsMutex);
   if (! UnitMap::doneFITS) {
-    ScopedMutexLock lock(UnitMap::fitsMutex);
-    if (! UnitMap::doneFITS) {
-      uInt cnt = 0;
-      const UnitName *Fname;
-      while (UnitMap::getNameFITS(Fname, cnt)) {
-        UnitMap::putUser(*Fname);
-        cnt++;
-      }
-      UnitMap::doneFITS = True;
+    uInt cnt = 0;
+    const UnitName *Fname;
+    while (UnitMap::getNameFITS(Fname, cnt)) {
+      UnitMap::putUser(*Fname);
+      cnt++;
     }
+    UnitMap::doneFITS = True;
   }
 }
 
 void UnitMap::clearFITS() {
   UnitMap::initUM();
+
+  ScopedMutexLock lock(UnitMap::fitsMutex);
   if (UnitMap::doneFITS) {
-    ScopedMutexLock lock(UnitMap::fitsMutex);
-    if (UnitMap::doneFITS) {
-      uInt cnt = 0;
-      const UnitName *Fname;
-      while (UnitMap::getNameFITS(Fname, cnt)) {
-        UnitMap::removeUser(*Fname);
-        cnt++;
-      }
-      UnitMap::doneFITS = False;
+    uInt cnt = 0;
+    const UnitName *Fname;
+    while (UnitMap::getNameFITS(Fname, cnt)) {
+      UnitMap::removeUser(*Fname);
+      cnt++;
     }
+    UnitMap::doneFITS = False;
   }
 }
 
