@@ -126,6 +126,19 @@ MDirection ROMSFieldColumns::referenceDirMeas(Int row, Double interTime) const
   }
 }
 
+MDirection ROMSFieldColumns::ephemerisDirMeas(Int row, Double interTime) const
+{
+  if(measCometIndex(row)>=0){
+    const MDirection zeroDir = MDirection(Quantity(0, "deg"), Quantity(0, "deg"));
+    return extractDirMeas(zeroDir,
+			  measCometIndex(row),
+			  interTime, timeMeas()(row));
+  }
+  else{
+    return referenceDirMeas(row, interTime);
+  }
+}
+
 
 MRadialVelocity ROMSFieldColumns::radVelMeas(Int row, Double interTime) const
 {
