@@ -36,39 +36,18 @@
 namespace casacore { //# NAMESPACE CASACORE - BEGIN
 
 TableExprConeNode::TableExprConeNode (FunctionType ftype, NodeDataType dtype,
-				      const TableExprNodeSet& source,
-				      uInt origin)
-: TableExprFuncNode (ftype, dtype, VTScalar, source),
-  origin_p          (origin)
+                                      const TableExprNodeSet& source,
+                                      const vector<TENShPtr>& nodes,
+                                      const Block<Int>& dtypeOper,
+                                      uInt origin)
+  : TableExprFuncNode (ftype, dtype, VTScalar, source,
+                       nodes, dtypeOper, Table()),
+    origin_p          (origin)
 {}
 
 TableExprConeNode::~TableExprConeNode()
 {}
 
-// Fill the children pointers of a node.
-// Also reduce the tree if possible by combining constants.
-// When one of the nodes is a constant, convert its type if
-// it does not match the other one.
-TableExprNodeRep* TableExprConeNode::fillNode
-                                   (TableExprConeNode* thisNode,
-				    PtrBlock<TableExprNodeRep*>& nodes,
-				    const Block<Int>& dtypeOper)
-{
-  return TableExprFuncNode::fillNode (thisNode, nodes, dtypeOper);
-}
-
-// Fill the children pointers of a node.
-void TableExprConeNode::fillChildNodes (TableExprConeNode* thisNode,
-					PtrBlock<TableExprNodeRep*>& nodes,
-					const Block<Int>& dtypeOper)
-{
-  TableExprFuncNode::fillChildNodes (thisNode, nodes, dtypeOper);
-}
-
-void TableExprConeNode::tryToConst()
-{
-}
-
 Bool TableExprConeNode::getBool (const TableExprId& id)
 {
   switch (funcType()) {
@@ -76,12 +55,12 @@ Bool TableExprConeNode::getBool (const TableExprId& id)
     {
       Array<double> srcArr  = operands()[0]->getArrayDouble(id).array();
       if (srcArr.nelements() != 2) {
-	throw TableInvExpr("First ANYCONE argument must have 2 values");
+        throw TableInvExpr("First ANYCONE argument must have multiple of 2 values");
       }
       Array<double> coneArr = operands()[1]->getArrayDouble(id).array();
       if (coneArr.nelements() % 3 != 0) {
-	throw TableInvExpr("Second ANYCONE argument "
-			   "must have multiple of 3 values");
+        throw TableInvExpr("Second ANYCONE argument "
+                           "must have multiple of 3 values");
       }
       Bool deleteSrc, deleteCone;
       const double* src  = srcArr.getStorage (deleteSrc);
@@ -90,14 +69,14 @@ Bool TableExprConeNode::getBool (const TableExprId& id)
       const double dec = src[1];
       Bool res = False;
       for (uInt i=0; i<coneArr.nelements(); i+=3) {
-	const double raCone  = cone[i];
-	const double decCone = cone[i+1];
-	const double radius  = cone[i+2];
-	if (cos(radius) <= sin(decCone) * sin(dec) +
-	                   cos(decCone) * cos(dec) * cos(raCone-ra)) {
-	  res = True;
-	  break;
-	}
+        const double raCone  = cone[i];
+        const double decCone = cone[i+1];
+        const double radius  = cone[i+2];
+        if (cos(radius) <= (sin(decCone) * sin(dec) +
+                            cos(decCone) * cos(dec) * cos(raCone-ra))) {
+          res = True;
+          break;
+        }
       }
       srcArr.freeStorage (src, deleteSrc);
       coneArr.freeStorage (cone, deleteCone);
@@ -107,12 +86,12 @@ Bool TableExprConeNode::getBool (const TableExprId& id)
     {
       Array<double> srcArr  = operands_p[0]->getArrayDouble(id).array();
       if (srcArr.nelements() != 2) {
-	throw TableInvExpr("First CONES argument must have 2 values");
+        throw TableInvExpr("First CONES argument must have multiple of 2 values");
       }
       Array<double> coneArr = operands_p[1]->getArrayDouble(id).array();
       if (coneArr.nelements() != 3) {
-	throw TableInvExpr("Second CONES argument "
-			   "must have multiple of 3 values");
+        throw TableInvExpr("Second CONES argument "
+                           "must have multiple of 3 values");
       }
       Bool deleteSrc, deleteCone;
       const double* src  = srcArr.getStorage (deleteSrc);
@@ -122,8 +101,8 @@ Bool TableExprConeNode::getBool (const TableExprId& id)
       const double raCone  = cone[0];
       const double decCone = cone[1];
       const double radius  = cone[2];
-      Bool res = cos(radius) <= sin(decCone) * sin(dec) +
-	                        cos(decCone) * cos(dec) * cos(raCone - ra);
+      Bool res = (cos(radius) <= (sin(decCone) * sin(dec) +
+                                  cos(decCone) * cos(dec) * cos(raCone - ra)));
       srcArr.freeStorage (src, deleteSrc);
       coneArr.freeStorage (cone, deleteCone);
       return res;
@@ -132,12 +111,12 @@ Bool TableExprConeNode::getBool (const TableExprId& id)
     {
       Array<double> srcArr  = operands()[0]->getArrayDouble(id).array();
       if (srcArr.nelements() != 2) {
-	throw TableInvExpr("First ANYCONE argument must have 2 values");
+        throw TableInvExpr("First ANYCONE argument must have multiple of 2 values");
       }
       Array<double> coneArr = operands()[1]->getArrayDouble(id).array();
       if (coneArr.nelements() % 2 != 0) {
-	throw TableInvExpr("Second ANYCONE3 argument "
-			   "must have multiple of 2 values");
+        throw TableInvExpr("Second ANYCONE3 argument "
+                           "must have multiple of 2 values");
       }
       // Radius can be a single value or an array.
       int nrrad = 1;
@@ -145,39 +124,39 @@ Bool TableExprConeNode::getBool (const TableExprId& id)
       const double* rad = 0;
       Array<double> radArr;
       if ( operands()[2]->valueType() == VTArray) {
-	radArr = operands()[2]->getArrayDouble(id).array();
-	nrrad = radArr.nelements();
+        radArr = operands()[2]->getArrayDouble(id).array();
+        nrrad = radArr.nelements();
       } else {
-	radval = operands()[2]->getDouble(id);
-	rad = &radval;
+        radval = operands()[2]->getDouble(id);
+        rad = &radval;
       }
       Bool deleteSrc, deleteCone, deleteRad;
       const double* src  = srcArr.getStorage (deleteSrc);
       const double* cone = coneArr.getStorage (deleteCone);
       if (rad != &radval) {
-	rad = radArr.getStorage (deleteRad);
+        rad = radArr.getStorage (deleteRad);
       }
       const double ra  = src[0];
       const double dec = src[1];
       Bool res = False;
       for (uInt i=0; i<coneArr.nelements(); i+=2) {
-	const double raCone  = cone[i];
-	const double decCone = cone[i+1];
-	double dist = sin(decCone) * sin(dec) +
-	              cos(decCone) * cos(dec) * cos(raCone-ra);
-	for (Int k=0; k<nrrad; k++) {
-	  const double radius  = rad[k];
-	  if (cos(radius) <= dist) {
-	    res = True;
-	    break;
-	  }
-	}
-	if (res) break;
+        const double raCone  = cone[i];
+        const double decCone = cone[i+1];
+        double dist = (sin(decCone) * sin(dec) +
+                       cos(decCone) * cos(dec) * cos(raCone-ra));
+        for (Int k=0; k<nrrad; k++) {
+          const double radius  = rad[k];
+          if (cos(radius) <= dist) {
+            res = True;
+            break;
+          }
+        }
+        if (res) break;
       }
       srcArr.freeStorage (src, deleteSrc);
       coneArr.freeStorage (cone, deleteCone);
       if (rad != &radval) {
-	radArr.freeStorage (rad, deleteRad);
+        radArr.freeStorage (rad, deleteRad);
       }
       return res;
     }
@@ -185,13 +164,13 @@ Bool TableExprConeNode::getBool (const TableExprId& id)
     {
       Array<double> srcArr  = operands()[0]->getArrayDouble(id).array();
       if (srcArr.nelements() != 2) {
-	throw TableInvExpr("First CONES argument "
-			   "must have 2 values");
+        throw TableInvExpr("First CONES argument "
+                           "must have multiple of 2 values");
       }
       Array<double> coneArr = operands()[1]->getArrayDouble(id).array();
       if (coneArr.nelements() % 2 != 0) {
-	throw TableInvExpr("Second CONES3 argument "
-			   "must have multiple of 2 values");
+        throw TableInvExpr("Second CONES3 argument "
+                           "must have multiple of 2 values");
       }
       Bool deleteSrc, deleteCone;
       const double* src  = srcArr.getStorage (deleteSrc);
@@ -201,15 +180,15 @@ Bool TableExprConeNode::getBool (const TableExprId& id)
       const double raCone  = cone[0];
       const double decCone = cone[1];
       const double radius  = operands()[2]->getDouble(id);
-      Bool res = cos(radius) <= sin(decCone) * sin(dec) +
-	                        cos(decCone) * cos(dec) * cos(raCone - ra);
+      Bool res = (cos(radius) <= (sin(decCone) * sin(dec) +
+                                  cos(decCone) * cos(dec) * cos(raCone - ra)));
       srcArr.freeStorage (src, deleteSrc);
       coneArr.freeStorage (cone, deleteCone);
       return res;
     }
   default:
     throw (TableInvExpr ("TableExprConeNode::getBool, "
-			 "unknown function"));
+                         "unknown function"));
   }
   return True;
 }
@@ -221,13 +200,13 @@ Int64 TableExprConeNode::getInt (const TableExprId& id)
     {
       Array<double> srcArr  = operands()[0]->getArrayDouble(id).array();
       if (srcArr.nelements() != 2) {
-	throw TableInvExpr("First FINDCONE argument "
-			   "must have 2 values");
+        throw TableInvExpr("First FINDCONE argument "
+                           "must have multiple of 2 values");
       }
       Array<double> coneArr = operands()[1]->getArrayDouble(id).array();
       if (coneArr.nelements() % 3 != 0) {
-	throw TableInvExpr("Second FINDCONE argument "
-			   "must have multiple of 3 values");
+        throw TableInvExpr("Second FINDCONE argument "
+                           "must have multiple of 3 values");
       }
       Bool deleteSrc, deleteCone;
       const double* src  = srcArr.getStorage (deleteSrc);
@@ -236,14 +215,14 @@ Int64 TableExprConeNode::getInt (const TableExprId& id)
       const double dec = src[1];
       Int res = -1;
       for (uInt i=0; i<coneArr.nelements(); i+=3) {
-	const double raCone  = cone[i];
-	const double decCone = cone[i+1];
-	const double radius  = cone[i+2];
-	if (cos(radius) <= sin(decCone) * sin(dec) +
-	                   cos(decCone) * cos(dec) * cos(raCone-ra)) {
-	  res = origin_p + i/3;
-	  break;
-	}
+        const double raCone  = cone[i];
+        const double decCone = cone[i+1];
+        const double radius  = cone[i+2];
+        if (cos(radius) <= (sin(decCone) * sin(dec) +
+                            cos(decCone) * cos(dec) * cos(raCone-ra))) {
+          res = origin_p + i/3;
+          break;
+        }
       }
       srcArr.freeStorage (src, deleteSrc);
       coneArr.freeStorage (cone, deleteCone);
@@ -253,13 +232,13 @@ Int64 TableExprConeNode::getInt (const TableExprId& id)
     {
       Array<double> srcArr  = operands()[0]->getArrayDouble(id).array();
       if (srcArr.nelements() != 2) {
-	throw TableInvExpr("First FINDCONE argument "
-			   "must have 2 values");
+        throw TableInvExpr("First FINDCONE argument "
+                           "must have multiple 2 values");
       }
       Array<double> coneArr = operands()[1]->getArrayDouble(id).array();
       if (coneArr.nelements() % 2 != 0) {
-	throw TableInvExpr("Second FINDCONE3 argument "
-			   "must have multiple of 2 values");
+        throw TableInvExpr("Second FINDCONE3 argument "
+                           "must have multiple of 2 values");
       }
       // Radius can be a single value or an array.
       int nrrad = 1;
@@ -267,45 +246,45 @@ Int64 TableExprConeNode::getInt (const TableExprId& id)
       const double* rad = 0;
       Array<double> radArr;
       if ( operands()[2]->valueType() == VTArray) {
-	radArr = operands()[2]->getArrayDouble(id).array();
-	nrrad = radArr.nelements();
+        radArr = operands()[2]->getArrayDouble(id).array();
+        nrrad = radArr.nelements();
       } else {
-	radval = operands()[2]->getDouble(id);
-	rad = &radval;
+        radval = operands()[2]->getDouble(id);
+        rad = &radval;
       }
       Bool deleteSrc, deleteCone, deleteRad;
       const double* src  = srcArr.getStorage (deleteSrc);
       const double* cone = coneArr.getStorage (deleteCone);
       if (rad != &radval) {
-	rad = radArr.getStorage (deleteRad);
+        rad = radArr.getStorage (deleteRad);
       }
       const double ra  = src[0];
       const double dec = src[1];
       Int res = -1;
       for (uInt i=0; i<coneArr.nelements(); i+=2) {
-	const double raCone  = cone[i];
-	const double decCone = cone[i+1];
-	double dist = sin(decCone) * sin(dec) +
-	              cos(decCone) * cos(dec) * cos(raCone-ra);
-	for (Int k=0; k<nrrad; k++) {
-	  const double radius  = rad[k];
-	  if (cos(radius) <= dist) {
-	    res = origin_p + k + nrrad*i/2;
-	    break;
-	  }
-	}
-	if (res >= 0) break;
+        const double raCone  = cone[i];
+        const double decCone = cone[i+1];
+        double dist = (sin(decCone) * sin(dec) +
+                       cos(decCone) * cos(dec) * cos(raCone-ra));
+        for (Int k=0; k<nrrad; k++) {
+          const double radius  = rad[k];
+          if (cos(radius) <= dist) {
+            res = origin_p + k + nrrad*i/2;
+            break;
+          }
+        }
+        if (res >= 0) break;
       }
       srcArr.freeStorage (src, deleteSrc);
       coneArr.freeStorage (cone, deleteCone);
       if (rad != &radval) {
-	radArr.freeStorage (rad, deleteRad);
+        radArr.freeStorage (rad, deleteRad);
       }
       return res;
     }
   default:
-    throw (TableInvExpr ("TableExprConeNode::getDouble, "
-			 "unknown function"));
+    throw (TableInvExpr ("TableExprConeNode::getInt, "
+                         "unknown function"));
   }
   return 0;
 }
@@ -313,9 +292,9 @@ Int64 TableExprConeNode::getInt (const TableExprId& id)
 
 TableExprNodeRep::NodeDataType TableExprConeNode::checkOperands
                                  (Block<Int>& dtypeOper,
-				  ValueType& resVT, Block<Int>&,
-				  FunctionType fType,
-				  PtrBlock<TableExprNodeRep*>& nodes)
+                                  ValueType& resVT, Block<Int>&,
+                                  FunctionType fType,
+                                  const vector<TENShPtr>& nodes)
 {
   int nrarg = 3;
   switch (fType) {
@@ -333,10 +312,10 @@ TableExprNodeRep::NodeDataType TableExprConeNode::checkOperands
     {
       checkNumOfArg (nrarg, nrarg, nodes);
       for (Int i=0; i<2; i++) {
-	if (nodes[i]->valueType() != VTArray) {
-	  throw TableInvExpr
-	    ("First 2 arguments of CONE functions must be double arrays");
-	}
+        if (nodes[i]->valueType() != VTArray) {
+          throw TableInvExpr
+            ("First 2 arguments of CONE functions must be double arrays");
+        }
       }
       // Result is a scalar or array.
       resVT = VTScalar;
@@ -346,41 +325,41 @@ TableExprNodeRep::NodeDataType TableExprConeNode::checkOperands
       // findcone returns an index value as integer.
       // This is a scalar if there is one source.
       if (fType == findconeFUNC  ||  fType == findcone3FUNC) {
-	if (nvalPos != 2) {
-	  resVT = VTArray;
-	}
-	return checkDT (dtypeOper, NTReal, NTInt, nodes);
+        if (nvalPos != 2) {
+          resVT = VTArray;
+        }
+        return checkDT (dtypeOper, NTReal, NTInt, nodes);
       }    
       // cones returns an array if there is more than one cone or radius.
       if (fType == conesFUNC) {
-	if (nvalCone != 3) {
-	  resVT = VTArray;
-	}
+        if (nvalCone != 3) {
+          resVT = VTArray;
+        }
       } else if (fType == cones3FUNC) {
-	if (nvalCone != 2  ||  nodes[2]->valueType() != VTScalar) {
-	  resVT = VTArray;
-	}
+        if (nvalCone != 2  ||  nodes[2]->valueType() != VTScalar) {
+          resVT = VTArray;
+        }
       }
       return checkDT (dtypeOper, NTReal, NTBool, nodes);
     }
   default:
     throw (TableInvExpr ("TableExprConeNode::checkOperands, "
-			 "function not contained in switch statement"));
+                         "function not contained in switch statement"));
   }
 }
 
-Int TableExprConeNode::findNelem (const TableExprNodeRep* node)
+Int TableExprConeNode::findNelem (const TENShPtr& node)
 {
   Int nelem = -1;
   if (node->valueType() == VTSet) {
-    const TableExprNodeSet* set = dynamic_cast<const TableExprNodeSet*>(node);
+    const TableExprNodeSet* set =
+      dynamic_cast<const TableExprNodeSet*>(node.get());
     AlwaysAssert (set, AipsError);
-    TableExprNodeRep* arr = set->setOrArray();
+    TENShPtr arr = set->setOrArray();
     if (arr->valueType() != VTArray) {
       throw TableInvExpr ("CONES argument is a non-array set");
     }
     nelem = arr->shape().product();
-    delete arr;
   } else {
     nelem = node->shape().product();
   }
@@ -392,9 +371,12 @@ Int TableExprConeNode::findNelem (const TableExprNodeRep* node)
 TableExprConeNodeArray::TableExprConeNodeArray (TableExprFuncNode::FunctionType ftype,
                                                 NodeDataType dtype,
                                                 const TableExprNodeSet& source,
+                                                const vector<TENShPtr>& nodes,
+                                                const Block<Int>& dtypeOper,
                                                 uInt origin)
-  : TableExprFuncNodeArray (ftype, dtype, VTArray, source, TaQLStyle()),
-  origin_p               (origin)
+  : TableExprFuncNodeArray (ftype, dtype, VTArray, source,
+                            nodes, dtypeOper, TaQLStyle()),
+    origin_p               (origin)
 {
   ndim_p = -1;
 }
@@ -402,30 +384,6 @@ TableExprConeNodeArray::TableExprConeNodeArray (TableExprFuncNode::FunctionType
 TableExprConeNodeArray::~TableExprConeNodeArray()
 {}
 
-// Fill the children pointers of a node.
-// Also reduce the tree if possible by combining constants.
-// When one of the nodes is a constant, convert its type if
-// it does not match the other one.
-TableExprNodeRep* TableExprConeNodeArray::fillNode
-                                   (TableExprConeNodeArray* thisNode,
-				    PtrBlock<TableExprNodeRep*>& nodes,
-				    const Block<Int>& dtypeOper)
-{
-  return TableExprFuncNodeArray::fillNode (thisNode, nodes, dtypeOper);
-}
-
-// Fill the children pointers of a node.
-void TableExprConeNodeArray::fillChildNodes (TableExprConeNodeArray* thisNode,
-                                             PtrBlock<TableExprNodeRep*>& nodes,
-                                             const Block<Int>& dtypeOper)
-{
-  TableExprFuncNode::fillChildNodes (thisNode->getChild(), nodes, dtypeOper);
-}
-
-void TableExprConeNodeArray::tryToConst()
-{
-}
-
 MArray<Bool> TableExprConeNodeArray::getArrayBool (const TableExprId& id)
 {
   switch (funcType()) {
@@ -433,13 +391,13 @@ MArray<Bool> TableExprConeNodeArray::getArrayBool (const TableExprId& id)
     {
       Array<double> srcArr  = operands()[0]->getArrayDouble(id).array();
       if (srcArr.nelements() % 2 != 0) {
-	throw TableInvExpr("First CONES argument "
-			   "must have multiple of 2 values");
+        throw TableInvExpr("First CONES argument "
+                           "must have multiple of 2 values");
       }
       Array<double> coneArr = operands()[1]->getArrayDouble(id).array();
       if (coneArr.nelements() % 3 != 0) {
-	throw TableInvExpr("Second CONES argument "
-			   "must have multiple of 3 values");
+        throw TableInvExpr("Second CONES argument "
+                           "must have multiple of 3 values");
       }
       // The result shape is a matrix (#cones, #sources).
       Int nsrc  = srcArr.nelements() / 2;
@@ -450,16 +408,16 @@ MArray<Bool> TableExprConeNodeArray::getArrayBool (const TableExprId& id)
       const double* cone = coneArr.getStorage (deleteCone);
       Bool* res = resArr.data();
       for (uInt j=0; j<srcArr.nelements(); j+=2) {
-	const double ra  = src[j];
-	const double sindec = sin(src[j+1]);
-	const double cosdec = cos(src[j+1]);
-	for (uInt i=0; i<coneArr.nelements(); i+=3) {
-	  const double raCone  = cone[i];
-	  const double decCone = cone[i+1];
-	  const double radius  = cone[i+2];
-	  *res++ = cos(radius) <= sin(decCone) * sindec +
-	                          cos(decCone) * cosdec * cos(raCone-ra);
-	}
+        const double ra  = src[j];
+        const double sindec = sin(src[j+1]);
+        const double cosdec = cos(src[j+1]);
+        for (uInt i=0; i<coneArr.nelements(); i+=3) {
+          const double raCone  = cone[i];
+          const double decCone = cone[i+1];
+          const double radius  = cone[i+2];
+          *res++ = cos(radius) <= (sin(decCone) * sindec +
+                                   cos(decCone) * cosdec * cos(raCone-ra));
+        }
       }
       srcArr.freeStorage (src, deleteSrc);
       coneArr.freeStorage (cone, deleteCone);
@@ -468,14 +426,14 @@ MArray<Bool> TableExprConeNodeArray::getArrayBool (const TableExprId& id)
   case TableExprFuncNode::cones3FUNC:
     {
       Array<double> srcArr  = operands()[0]->getArrayDouble(id).array();
-      if (srcArr.nelements() != 2) {
-	throw TableInvExpr("First CONES3 argument "
-			   "must have multiple of 2 values");
+      if (srcArr.nelements() % 2 != 0) {
+        throw TableInvExpr("First CONES3 argument "
+                           "must have multiple of 2 values");
       }
       Array<double> coneArr = operands()[1]->getArrayDouble(id).array();
       if (coneArr.nelements() % 2 != 0) {
-	throw TableInvExpr("Second CONES3 argument "
-			   "must have multiple of 2 values");
+        throw TableInvExpr("Second CONES3 argument "
+                           "must have multiple of 2 values");
       }
       // Radius can be a single value or an array.
       int nrrad = 1;
@@ -483,11 +441,11 @@ MArray<Bool> TableExprConeNodeArray::getArrayBool (const TableExprId& id)
       const double* rad = 0;
       Array<double> radArr;
       if ( operands()[2]->valueType() == VTArray) {
-	radArr = operands()[2]->getArrayDouble(id).array();
-	nrrad = radArr.nelements();
+        radArr = operands()[2]->getArrayDouble(id).array();
+        nrrad = radArr.nelements();
       } else {
-	radval = operands()[2]->getDouble(id);
-	rad = &radval;
+        radval = operands()[2]->getDouble(id);
+        rad = &radval;
       }
       // The result shape is a cube (#radii, #cones, #sources).
       Int nsrc  = srcArr.nelements() / 2;
@@ -496,35 +454,35 @@ MArray<Bool> TableExprConeNodeArray::getArrayBool (const TableExprId& id)
       const double* src  = srcArr.getStorage (deleteSrc);
       const double* cone = coneArr.getStorage (deleteCone);
       if (rad != &radval) {
-	rad = radArr.getStorage (deleteRad);
+        rad = radArr.getStorage (deleteRad);
       }
       Array<Bool> resArr(IPosition(3,nrrad,ncone,nsrc));
       Bool* res = resArr.data();
       for (uInt j=0; j<srcArr.nelements(); j+=2) {
-	const double ra  = src[j];
-	const double dec = src[j+1];
-	for (uInt i=0; i<coneArr.nelements(); i+=2) {
-	  const double raCone  = cone[i];
-	  const double decCone = cone[i+1];
-	  double dist = sin(decCone) * sin(dec) +
-	                cos(decCone) * cos(dec) * cos(raCone-ra);
+        const double ra  = src[j];
+        const double dec = src[j+1];
+        for (uInt i=0; i<coneArr.nelements(); i+=2) {
+          const double raCone  = cone[i];
+          const double decCone = cone[i+1];
+          double dist = (sin(decCone) * sin(dec) +
+                         cos(decCone) * cos(dec) * cos(raCone-ra));
 
-	  for (Int k=0; k<nrrad; k++) {
-	    const double radius = rad[k];
-	    *res++ = cos(radius) <= dist;
-	  }
-	}
+          for (Int k=0; k<nrrad; k++) {
+            const double radius = rad[k];
+            *res++ = cos(radius) <= dist;
+          }
+        }
       }
       srcArr.freeStorage (src, deleteSrc);
       coneArr.freeStorage (cone, deleteCone);
       if (rad != &radval) {
-	radArr.freeStorage (rad, deleteRad);
+        radArr.freeStorage (rad, deleteRad);
       }
       return MArray<Bool>(resArr);
     }
   default:
     throw (TableInvExpr ("TableExprConeNodeArray::getArrayBool, "
-			 "unknown function"));
+                         "unknown function"));
   }
 }
 
@@ -535,22 +493,22 @@ MArray<Int64> TableExprConeNodeArray::getArrayInt (const TableExprId& id)
     {
       Array<double> srcArr  = operands()[0]->getArrayDouble(id).array();
       if (srcArr.nelements() % 2 != 0) {
-	throw TableInvExpr("First FINDCONE argument "
-			   "must have multiple of 2 values");
+        throw TableInvExpr("First FINDCONE argument "
+                           "must have multiple of 2 values");
       }
       Array<double> coneArr = operands()[1]->getArrayDouble(id).array();
       if (coneArr.nelements() % 3 != 0) {
-	throw TableInvExpr("Second FINDCONE argument "
-			   "must have multiple of 3 values");
+        throw TableInvExpr("Second FINDCONE argument "
+                           "must have multiple of 3 values");
       }
       // The result shape is the source array shape.
       IPosition shpc = srcArr.shape();
       IPosition shp;
       if (shpc.nelements() > 1  &&  shpc[0] == 2) {
-	shp = shpc.getLast (shpc.nelements() - 1);
+        shp = shpc.getLast (shpc.nelements() - 1);
       } else {
-	shp = shpc;
-	shp[0] = shp[0] / 2;
+        shp = shpc;
+        shp[0] = shp[0] / 2;
       }
       Array<Int64> resArr(shp);
       Bool deleteSrc, deleteCone;
@@ -558,20 +516,20 @@ MArray<Int64> TableExprConeNodeArray::getArrayInt (const TableExprId& id)
       const double* cone = coneArr.getStorage (deleteCone);
       Int64* res = resArr.data();
       for (uInt j=0; j<srcArr.nelements(); j+=2) {
-	const double ra  = src[j];
-	const double dec = src[j+1];
-	*res = -1;
-	for (uInt i=0; i<coneArr.nelements(); i+=3) {
-	  const double raCone  = cone[i];
-	  const double decCone = cone[i+1];
-	  const double radius  = cone[i+2];
-	  if (cos(radius) <= sin(decCone) * sin(dec) +
-	                     cos(decCone) * cos(dec) * cos(raCone-ra)) {
-	    *res = origin_p + i/3;
-	    break;
-	  }
-	}
-	res++;
+        const double ra  = src[j];
+        const double dec = src[j+1];
+        *res = -1;
+        for (uInt i=0; i<coneArr.nelements(); i+=3) {
+          const double raCone  = cone[i];
+          const double decCone = cone[i+1];
+          const double radius  = cone[i+2];
+          if (cos(radius) <= (sin(decCone) * sin(dec) +
+                              cos(decCone) * cos(dec) * cos(raCone-ra))) {
+            *res = origin_p + i/3;
+            break;
+          }
+        }
+        res++;
       }
       srcArr.freeStorage (src, deleteSrc);
       coneArr.freeStorage (cone, deleteCone);
@@ -581,73 +539,67 @@ MArray<Int64> TableExprConeNodeArray::getArrayInt (const TableExprId& id)
     {
       Array<double> srcArr  = operands()[0]->getArrayDouble(id).array();
       if (srcArr.nelements() % 2 != 0) {
-	throw TableInvExpr("First FINDCONE argument "
-			   "must have multiple of 2 values");
+        throw TableInvExpr("First FINDCONE argument "
+                           "must have multiple of 2 values");
       }
       Array<double> coneArr = operands()[1]->getArrayDouble(id).array();
       if (coneArr.nelements() % 2 != 0) {
-	throw TableInvExpr("Second FINDCONE3 argument "
-			   "must have multiple of 2 values");
+        throw TableInvExpr("Second FINDCONE3 argument "
+                           "must have multiple of 2 values");
       }
       // Radius can be a single value or an array.
       int nrrad = 1;
-      double radval;
-      const double* rad = 0;
       Array<double> radArr;
       if ( operands()[2]->valueType() == VTArray) {
-	radArr = operands()[2]->getArrayDouble(id).array();
-	nrrad = radArr.nelements();
+        radArr = operands()[2]->getArrayDouble(id).array();
+        nrrad = radArr.nelements();
       } else {
-	radval = operands()[2]->getDouble(id);
-	rad = &radval;
+        radArr.resize(IPosition(1,1));
+        radArr.data()[0] = operands()[2]->getDouble(id);
+        nrrad = 1;
       }
       // The result shape is the source array shape.
       IPosition shpc = srcArr.shape();
       IPosition shp;
       if (shpc.nelements() > 1  &&  shpc[0] == 2) {
-	shp = shpc.getLast (shpc.nelements() - 1);
+        shp = shpc.getLast (shpc.nelements() - 1);
       } else {
-	shp = shpc;
-	shp[0] = shp[0] / 2;
+        shp = shpc;
+        shp[0] = shp[0] / 2;
       }
       Bool deleteSrc, deleteCone, deleteRad;
       const double* src  = srcArr.getStorage (deleteSrc);
       const double* cone = coneArr.getStorage (deleteCone);
-      if (rad != &radval) {
-	rad = radArr.getStorage (deleteRad);
-      }
+      const double* rad = radArr.getStorage (deleteRad);
       Array<Int64> resArr(shp);
       Int64* res = resArr.data();
       for (uInt j=0; j<srcArr.nelements(); j+=2) {
-	const double ra  = src[j];
-	const double dec = src[j+1];
-	*res = -1;
-	for (uInt i=0; i<coneArr.nelements(); i+=2) {
-	  const double raCone  = cone[i];
-	  const double decCone = cone[i+1];
-	  const double radius  = cone[i+2];
-	  double dist = sin(decCone) * sin(dec) +
-	                cos(decCone) * cos(dec) * cos(raCone-ra);
-	  for (Int k=0; k<nrrad; k++) {
-	    if (cos(radius) <= dist) {
-	      *res = origin_p + k + nrrad*i/2;
-	      break;
-	    }
-	  }
-	  if (*res >= 0) break;
-	}
-	res++;
+        const double ra  = src[j];
+        const double dec = src[j+1];
+        *res = -1;
+        for (uInt i=0; i<coneArr.nelements(); i+=2) {
+          const double raCone  = cone[i];
+          const double decCone = cone[i+1];
+          double dist = (sin(decCone) * sin(dec) +
+                         cos(decCone) * cos(dec) * cos(raCone-ra));
+          for (Int k=0; k<nrrad; k++) {
+            if (cos(rad[k]) <= dist) {
+              *res = origin_p + k + nrrad*i/2;
+              break;
+            }
+          }
+          if (*res >= 0) break;
+        }
+        res++;
       }
       srcArr.freeStorage (src, deleteSrc);
       coneArr.freeStorage (cone, deleteCone);
-      if (rad != &radval) {
-	radArr.freeStorage (rad, deleteRad);
-      }
+      radArr.freeStorage (rad, deleteRad);
       return MArray<Int64>(resArr);
     }
   default:
-    throw (TableInvExpr ("TableExprConeNodeArray::getArrayDouble, "
-			 "unknown function"));
+    throw (TableInvExpr ("TableExprConeNodeArray::getArrayInt, "
+                         "unknown function"));
   }
 }
 
