@@ -51,68 +51,53 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
 TableExprFuncNode::TableExprFuncNode (FunctionType ftype, NodeDataType dtype,
 				      ValueType vtype,
 				      const TableExprNodeSet& source,
+                                      const vector<TENShPtr>& nodes,
+                                      const Block<Int>& dtypeOper,
                                       const Table& table)
 : TableExprNodeMulti (dtype, vtype, OtFunc, source),
   funcType_p         (ftype),
   argDataType_p      (dtype),
   scale_p            (1),
   table_p            (table)
-{}
+{
+  // Fill child nodes as needed. It also fills operands_p.
+  fillChildNodes (nodes, dtypeOper);
+  // Set the unit for some functions.
+  fillUnits();
+  // Some functions on a variable can already give a constant result.
+  tryToConst();
+}
 
 TableExprFuncNode::~TableExprFuncNode()
 {}
 
-// Fill the children pointers of a node.
-// Also reduce the tree if possible by combining constants.
-// If one of the nodes is a constant, convert its type if
-// it does not match the other one.
-TableExprNodeRep* TableExprFuncNode::fillNode
-                                   (TableExprFuncNode* thisNode,
-				    PtrBlock<TableExprNodeRep*>& nodes,
-				    const Block<Int>& dtypeOper)
+void TableExprFuncNode::fillUnits()
 {
-    // Fill child nodes as needed. It also fills operands_p.
-    fillChildNodes (thisNode, nodes, dtypeOper);
-    // Set the unit for some functions.
-    Double scale = fillUnits (thisNode, thisNode->operands_p,
-                              thisNode->funcType());
-    thisNode->setScale (scale);
-    // Some functions on a variable can already give a constant result.
-    thisNode->tryToConst();
-    if (thisNode->operands_p.nelements() > 0) {
-	return convertNode (thisNode, True);
-    }
-    return thisNode;
-}
-
-Double TableExprFuncNode::fillUnits (TableExprNodeRep* node,
-                                     PtrBlock<TableExprNodeRep*>& nodes,
-                                     FunctionType func)
-{
-  Double scale = 1;
-  if (func == cFUNC) {
-    node->setUnit ("m/s");
+  if (funcType_p == cFUNC) {
+    setUnit ("m/s");
   }
-  if (nodes.nelements() > 0) {
-    const Unit& childUnit = nodes[0]->unit();
-    switch (func) {
+  if (operands_p.size() > 0) {
+    const Unit& childUnit = operands_p[0]->unit();
+    switch (funcType_p) {
     case asinFUNC:
     case acosFUNC:
     case atanFUNC:
     case atan2FUNC:
     case timeFUNC:
     case argFUNC:
-      // These functions return radians.
-      node->setUnit ("rad");
+      // These functions return radians (if operand is not complex).
+      if (operands_p[0]->dataType() != NTComplex) {
+        setUnit ("rad");
+      }
       break;
     case mjdFUNC:
       // These functions return days.
-      node->setUnit ("d");
+      setUnit ("d");
       break;
     case mjdtodateFUNC:
       // These functions require days.
       if (! childUnit.empty()) {
-        TableExprNodeUnit::adaptUnit (nodes[0], "d");
+        TableExprNodeUnit::adaptUnit (operands_p[0], "d");
       }
       break;
     case absFUNC:
@@ -125,6 +110,8 @@ Double TableExprFuncNode::fillUnits (TableExprNodeRep* node,
     case fmodFUNC:
     case arrsumFUNC:
     case arrsumsFUNC:
+    case runsumFUNC:
+    case boxsumFUNC:
     case arrminFUNC:
     case arrminsFUNC:
     case runminFUNC:
@@ -155,6 +142,8 @@ Double TableExprFuncNode::fillUnits (TableExprNodeRep* node,
     case boxmedianFUNC:
     case arrfractileFUNC:
     case arrfractilesFUNC:
+    case runfractileFUNC:
+    case boxfractileFUNC:
     case arrayFUNC:
     case transposeFUNC:
     case resizeFUNC:
@@ -181,12 +170,14 @@ Double TableExprFuncNode::fillUnits (TableExprNodeRep* node,
     case gmedianFUNC:
     case gfractileFUNC:
       // These functions return the same unit as their child.
-      node->setUnit (childUnit);
+      setUnit (childUnit);
       break;
     case normFUNC:
     case squareFUNC:
     case arrsumsqrFUNC:
     case arrsumsqrsFUNC:
+    case runsumsqrFUNC:
+    case boxsumsqrFUNC:
     case gsumsqrFUNC:
     case gsumsqrsFUNC:
     case arrvarianceFUNC:
@@ -198,13 +189,13 @@ Double TableExprFuncNode::fillUnits (TableExprNodeRep* node,
      // These functions return the square of their child.
       if (! childUnit.empty()) {
         Quantity q(1., childUnit);
-        node->setUnit ((q*q).getFullUnit());
+        setUnit ((q*q).getFullUnit());
       }
       break;
     case cubeFUNC:
       if (! childUnit.empty()) {
         Quantity q(1., childUnit);
-        node->setUnit ((q*q*q).getFullUnit());
+        setUnit ((q*q*q).getFullUnit());
       }
       break;
     case sqrtFUNC:
@@ -213,8 +204,8 @@ Double TableExprFuncNode::fillUnits (TableExprNodeRep* node,
         Quantity q(1., childUnit);
         Quantity qs(sqrt(q));
         // sqrt result is always in SI units, so scaling might be involved.
-        scale = qs.getValue();
-        node->setUnit (qs.getFullUnit());
+        scale_p = qs.getValue();
+        setUnit (qs.getFullUnit());
       }
       break;
     case sinFUNC:
@@ -224,29 +215,30 @@ Double TableExprFuncNode::fillUnits (TableExprNodeRep* node,
     case dmsFUNC:
     case hdmsFUNC:
       // These functions return no unit, but their child must be in radians.
+      // Note that in case of DComplex argument there is no unit.
       if (! childUnit.empty()) {
-        TableExprNodeUnit::adaptUnit (nodes[0], "rad");
+        TableExprNodeUnit::adaptUnit (operands_p[0], "rad");
       }
       break;
     case iifFUNC:
-      node->setUnit (makeEqualUnits (nodes, 1, nodes.nelements()));
+      setUnit (makeEqualUnits (operands_p, 1, operands_p.size()));
       break;
     case complexFUNC:
     case minFUNC:
     case maxFUNC:
-      node->setUnit (makeEqualUnits (nodes, 0, nodes.nelements()));
+      setUnit (makeEqualUnits (operands_p, 0, operands_p.size()));
       break;
     case near2FUNC:
     case nearabs2FUNC:
     case near3FUNC:
-      makeEqualUnits (nodes, 0, 2);
+      makeEqualUnits (operands_p, 0, 2);
       break;
     case nearabs3FUNC:
-      makeEqualUnits (nodes, 0, 3);
+      makeEqualUnits (operands_p, 0, 3);
       break;
     case angdistFUNC:
     case angdistxFUNC:
-      node->setUnit ("rad");
+      setUnit ("rad");
       // fall through
     case conesFUNC:
     case cones3FUNC:
@@ -254,8 +246,8 @@ Double TableExprFuncNode::fillUnits (TableExprNodeRep* node,
     case anycone3FUNC:
     case findconeFUNC:
     case findcone3FUNC:
-      for (uInt i=0; i<nodes.nelements(); ++i) {
-        TableExprNodeUnit::adaptUnit (nodes[i], "rad");
+      for (uInt i=0; i<operands_p.size(); ++i) {
+        TableExprNodeUnit::adaptUnit (operands_p[i], "rad");
       }
       break;
     default:
@@ -263,12 +255,10 @@ Double TableExprFuncNode::fillUnits (TableExprNodeRep* node,
       break;
     }
   }
-  return scale;
 }
 
-const Unit& TableExprFuncNode::makeEqualUnits
-                             (PtrBlock<TableExprNodeRep*>& nodes,
-			      uInt starg, uInt endarg)
+const Unit& TableExprFuncNode::makeEqualUnits (vector<TENShPtr>& nodes,
+                                               uInt starg, uInt endarg)
 {
   // These functions have multiple children, which must have the same unit.
   // The first real unit is chosen as the result unit.
@@ -288,64 +278,61 @@ const Unit& TableExprFuncNode::makeEqualUnits
 }
 
 // Fill the children pointers of a node.
-void TableExprFuncNode::fillChildNodes (TableExprFuncNode* thisNode,
-					PtrBlock<TableExprNodeRep*>& nodes,
+void TableExprFuncNode::fillChildNodes (const vector<TENShPtr>& nodes,
 					const Block<Int>& dtypeOper)
 {
-    uInt i;
-    // Copy block of children.
-    // Determine if common argument type is Int, Double or Complex.
-    // (this is used by some functions like near and norm).
-    thisNode->operands_p.resize (nodes.nelements());
-    thisNode->argDataType_p = NTInt;
-    for (i=0; i<nodes.nelements(); i++) {
-	thisNode->operands_p[i] = nodes[i]->link();
-	if (nodes[i]->dataType() == NTDouble
-          &&  thisNode->argDataType_p != NTComplex) {
-	    thisNode->argDataType_p = NTDouble;
-	} else if (nodes[i]->dataType() == NTComplex) {
-	    thisNode->argDataType_p = NTComplex;
-	}
+  // Copy block of children.
+  // Determine if common argument type is Int, Double or Complex.
+  // (this is used by some functions like near and norm).
+  operands_p.resize (nodes.size());
+  argDataType_p = NTInt;
+  for (uInt i=0; i<nodes.size(); i++) {
+    operands_p[i] = nodes[i];
+    if (nodes[i]->dataType() == NTDouble
+        &&  argDataType_p != NTComplex) {
+      argDataType_p = NTDouble;
+    } else if (nodes[i]->dataType() == NTComplex) {
+      argDataType_p = NTComplex;
     }
-    // Convert String to Date if needed
-    for (i=0; i<nodes.nelements(); i++) {
-	if (dtypeOper[i] == NTDate) {
-            if (nodes[i]->dataType() == NTString) {
-                TableExprNode dNode = datetime (thisNode->operands_p[i]);
-                unlink (thisNode->operands_p[i]);
-                thisNode->operands_p[i] = getRep (dNode)->link();
-            } else if (nodes[i]->dataType() == NTDouble) {
-                TableExprNode dNode = mjdtodate (thisNode->operands_p[i]);
-                unlink (thisNode->operands_p[i]);
-                thisNode->operands_p[i] = getRep (dNode)->link();
-            }
-        }
+  }
+  // Convert String to Date if needed
+  for (uInt i=0; i<nodes.size(); i++) {
+    if (i < dtypeOper.size()  &&  dtypeOper[i] == NTDate) {
+      if (nodes[i]->dataType() == NTString) {
+        TableExprNode dNode = datetime (operands_p[i]);
+        operands_p[i] = dNode.getRep();
+      } else if (nodes[i]->dataType() == NTDouble  ||
+                 nodes[i]->dataType() == NTInt) {
+        TableExprNode dNode = mjdtodate (operands_p[i]);
+        operands_p[i] = dNode.getRep();
+      }
     }
+  }
 }
 
 void TableExprFuncNode::tryToConst()
 {
-    switch (funcType_p) {
-    case ndimFUNC:
-	if (operands_p[0]->ndim() >= 0) {
-	    exprtype_p = Constant;
-	}
-	break;
-    case nelemFUNC:
-    case isdefFUNC:
-    case isnullFUNC:
-	if (operands_p[0]->ndim() == 0
-        ||  operands_p[0]->shape().nelements() > 0  ) {
-	    exprtype_p = Constant;
-	}
-	break;
-    case iscolFUNC:
-    case iskeyFUNC:
-        exprtype_p = Constant;
-        break;
-    default:
-	break;
+  switch (funcType_p) {
+  case ndimFUNC:
+    if (operands_p[0]->ndim() >= 0) {
+      exprtype_p = Constant;
     }
+    break;
+  case nelemFUNC:
+  case isdefFUNC:
+  case isnullFUNC:
+    if (operands_p[0]->ndim() == 0
+        ||  operands_p[0]->shape().size() > 0  ) {
+      exprtype_p = Constant;
+    }
+    break;
+  case iscolFUNC:
+  case iskeyFUNC:
+    exprtype_p = Constant;
+    break;
+  default:
+    break;
+  }
 }
 
 Bool TableExprFuncNode::getBool (const TableExprId& id)
@@ -364,12 +351,12 @@ Bool TableExprFuncNode::getBool (const TableExprId& id)
         return (operands_p[0]->getDouble(id) != 0);
       }
       return string2Bool (operands_p[0]->getString(id));
-    case anyFUNC:
+    case arranyFUNC:
         if (operands_p[0]->valueType() == VTArray) {
             return anyTrue (operands_p[0]->getArrayBool(id));
 	}
 	return operands_p[0]->getBool (id);
-    case allFUNC:
+    case arrallFUNC:
         if (operands_p[0]->valueType() == VTArray) {
             return allTrue (operands_p[0]->getArrayBool(id));
 	}
@@ -590,12 +577,12 @@ Int64 TableExprFuncNode::getInt (const TableExprId& id)
 	    Int64 val = operands_p[0]->getInt(id);
 	    return val * val;
 	}
-    case ntrueFUNC:
+    case arrntrueFUNC:
         if (operands_p[0]->valueType() == VTArray) {
             return ntrue (operands_p[0]->getArrayBool (id));
 	}
 	return (operands_p[0]->getBool(id)  ?  1 : 0);
-    case nfalseFUNC:
+    case arrnfalseFUNC:
         if (operands_p[0]->valueType() == VTArray) {
             return nfalse (operands_p[0]->getArrayBool (id));
 	}
@@ -604,7 +591,7 @@ Int64 TableExprFuncNode::getInt (const TableExprId& id)
       {
         // Return fixed dimensionality if available.
         Int64 nrdim = operands_p[0]->ndim();
-	return (nrdim >= 0  ?  nrdim : operands_p[0]->shape(id).nelements());
+	return (nrdim >= 0  ?  nrdim : operands_p[0]->shape(id).size());
       }
     case nelemFUNC:
 	return (operands_p[0]->valueType() == VTScalar  ?
@@ -893,6 +880,19 @@ DComplex TableExprFuncNode::getDComplex (const TableExprId& id)
 	}
 	return val0;
       }
+    case asinFUNC:
+	return asin  (operands_p[0]->getDComplex(id));
+    case acosFUNC:
+	return acos  (operands_p[0]->getDComplex(id));
+    case atanFUNC:
+	return atan  (operands_p[0]->getDComplex(id));
+    case tanFUNC:
+	return tan   (operands_p[0]->getDComplex(id));
+    case tanhFUNC:
+	return tanh  (operands_p[0]->getDComplex(id));
+    case atan2FUNC:
+	return atan2 (operands_p[0]->getDComplex(id),
+                      operands_p[1]->getDComplex(id));
     case complexFUNC:
         // A single argument is always a string.
         if (operands_p.size() == 1) {
@@ -980,6 +980,7 @@ String TableExprFuncNode::getString (const TableExprId& id)
         Int64 st = operands_p[1]->getInt (id);
         if (st < 0) st += str.size();
         if (st < 0) st = 0;
+        if (st > Int64(str.size())) st = str.size();
         Int64 sz = String::npos;
         if (operands_p.size() > 2) {
           sz = std::max (Int64(0), operands_p[2]->getInt (id));
@@ -1093,7 +1094,7 @@ MVTime TableExprFuncNode::getDate (const TableExprId& id)
 }
 
 void TableExprFuncNode::getPrintFormat (String& fmt, Int& width, Int& prec,
-                                        const PtrBlock<TableExprNodeRep*>& operands,
+                                        const vector<TENShPtr>& operands,
                                         const TableExprId& id)
 {
   width = 0;
@@ -1298,7 +1299,7 @@ TableExprNodeRep::NodeDataType TableExprFuncNode::checkOperands
                                  (Block<Int>& dtypeOper,
 				  ValueType& resVT, Block<Int>&,
 				  FunctionType fType,
-				  PtrBlock<TableExprNodeRep*>& nodes)
+				  vector<TENShPtr>& nodes)
 {
     uInt i;
     // The default returned value type is a scalar.
@@ -1335,12 +1336,12 @@ TableExprNodeRep::NodeDataType TableExprFuncNode::checkOperands
     case arrsumsqrFUNC:
 	checkNumOfArg (1, 1, nodes);
 	return checkDT (dtypeOper, NTNumeric, NTNumeric, nodes);
-    case anyFUNC:
-    case allFUNC:
+    case arranyFUNC:
+    case arrallFUNC:
 	checkNumOfArg (1, 1, nodes);
 	return checkDT (dtypeOper, NTBool, NTBool, nodes);
-    case ntrueFUNC:
-    case nfalseFUNC:
+    case arrntrueFUNC:
+    case arrnfalseFUNC:
 	checkNumOfArg (1, 1, nodes);
 	return checkDT (dtypeOper, NTBool, NTInt, nodes);
     case nelemFUNC:
@@ -1404,7 +1405,7 @@ TableExprNodeRep::NodeDataType TableExprFuncNode::checkOperands
     default:
 	break;
     }
-    // The following functions accept one array or scalar and a set of
+    // The following functions accept one array and a set of
     // one or more scalars.
     // They return an array.
     switch (fType) {
@@ -1420,10 +1421,13 @@ TableExprNodeRep::NodeDataType TableExprFuncNode::checkOperands
     case arrrmssFUNC:
     case arrmediansFUNC:
     case arrfractilesFUNC:
-    case anysFUNC:
-    case allsFUNC:
-    case ntruesFUNC:
-    case nfalsesFUNC:
+    case arranysFUNC:
+    case arrallsFUNC:
+    case arrntruesFUNC:
+    case arrnfalsesFUNC:
+    case runsumFUNC:
+    case runproductFUNC:
+    case runsumsqrFUNC:
     case runminFUNC:
     case runmaxFUNC:
     case runmeanFUNC:
@@ -1432,8 +1436,14 @@ TableExprNodeRep::NodeDataType TableExprFuncNode::checkOperands
     case runavdevFUNC:
     case runrmsFUNC:
     case runmedianFUNC:
+    case runfractileFUNC:
     case runanyFUNC:
     case runallFUNC:
+    case runntrueFUNC:
+    case runnfalseFUNC:
+    case boxsumFUNC:
+    case boxproductFUNC:
+    case boxsumsqrFUNC:
     case boxminFUNC:
     case boxmaxFUNC:
     case boxmeanFUNC:
@@ -1442,8 +1452,11 @@ TableExprNodeRep::NodeDataType TableExprFuncNode::checkOperands
     case boxavdevFUNC:
     case boxrmsFUNC:
     case boxmedianFUNC:
+    case boxfractileFUNC:
     case boxanyFUNC:
     case boxallFUNC:
+    case boxntrueFUNC:
+    case boxnfalseFUNC:
     case arrayFUNC:
     case transposeFUNC:
     case diagonalFUNC:
@@ -1458,8 +1471,22 @@ TableExprNodeRep::NodeDataType TableExprFuncNode::checkOperands
 	case arrsumsFUNC:
 	case arrproductsFUNC:
 	case arrsumsqrsFUNC:
+	case runsumFUNC:
+	case runproductFUNC:
+	case runsumsqrFUNC:
+	case boxsumFUNC:
+	case boxproductFUNC:
+	case boxsumsqrFUNC:
 	    dtin = dtout = NTNumeric;
 	    break;
+        case arrminsFUNC:
+        case arrmaxsFUNC:
+        case runminFUNC:
+        case runmaxFUNC:
+        case boxminFUNC:
+        case boxmaxFUNC:
+            dtin = dtout = NTReal;
+            break;
         case arrmeansFUNC:
         case runmeanFUNC:
         case boxmeanFUNC:
@@ -1467,18 +1494,24 @@ TableExprNodeRep::NodeDataType TableExprFuncNode::checkOperands
             dtout = NTDouCom;
             break;
 	case arrfractilesFUNC:
+	case runfractileFUNC:
+	case boxfractileFUNC:
 	    axarg = 2;
 	    break;
-	case anysFUNC:
-	case allsFUNC:
+	case arranysFUNC:
+	case arrallsFUNC:
 	case runanyFUNC:
 	case runallFUNC:
 	case boxanyFUNC:
 	case boxallFUNC:
 	    dtin = dtout = NTBool;
 	    break;
-	case ntruesFUNC:
-	case nfalsesFUNC:
+	case arrntruesFUNC:
+	case arrnfalsesFUNC:
+	case runntrueFUNC:
+	case runnfalseFUNC:
+	case boxntrueFUNC:
+	case boxnfalseFUNC:
 	    dtin = NTBool;
             dtout = NTInt;
 	    break;
@@ -1507,7 +1540,7 @@ TableExprNodeRep::NodeDataType TableExprFuncNode::checkOperands
 	    }
 	}
 	// Check if first argument has correct type.
-	PtrBlock<TableExprNodeRep*> nodeTmp(1);
+	vector<TENShPtr> nodeTmp(1);
 	nodeTmp[0] = nodes[0];
 	Block<Int> dtypeTmp;    // Gets filled in by checkDT
 	dtout = checkDT (dtypeTmp, dtin, dtout, nodeTmp);
@@ -1519,7 +1552,7 @@ TableExprNodeRep::NodeDataType TableExprFuncNode::checkOperands
                 (nodes[i]->dataType() != NTInt  &&
                  nodes[i]->dataType() != NTDouble)) {
 	      throw TableInvExpr ("2nd argument of function FRACTILE "
-				  "has to be an real scalar");
+				  "has to be a real scalar");
 	    }
 	  }
 	}
@@ -1534,7 +1567,7 @@ TableExprNodeRep::NodeDataType TableExprFuncNode::checkOperands
         // Check if an optional arg (voor expand) is an Int.
         if (nodes.size() == axarg+optarg+1) {
           if (nodes[axarg+optarg]->dataType() != NTInt) {
-            throw TableInvExpr ("The 3rd argument of RESIZE"
+            throw TableInvExpr ("3rd argument of function RESIZE"
                                 " has to be integer");
           }
         }
@@ -1546,7 +1579,7 @@ TableExprNodeRep::NodeDataType TableExprFuncNode::checkOperands
     // The following functions accept scalars and arrays.
     // They return an array if one of the input arguments is an array.
     // If a function has no arguments, it results in a scalar.
-    for (i=0; i< nodes.nelements(); i++) {
+    for (i=0; i< nodes.size(); i++) {
         ValueType vt = nodes[i]->valueType();
 	if (vt == VTArray) {
 	    resVT = vt;
@@ -1577,7 +1610,7 @@ TableExprNodeRep::NodeDataType TableExprFuncNode::checkOperands
           if (nodes[i]->valueType() != VTScalar
               ||  nodes[i]->dataType() != NTInt) {
             throw TableInvExpr ("2nd and optional 3rd argument of function "
-                                " SUBSTR have to be integer scalars");
+                                "SUBSTR have to be integer scalars");
           }
         }
 	dtypeOper.resize (nodes.size());
@@ -1594,7 +1627,7 @@ TableExprNodeRep::NodeDataType TableExprFuncNode::checkOperands
             ||  (nodes[1]->dataType() != NTString  &&
                  nodes[1]->dataType() != NTRegex)) {
           throw TableInvExpr ("2nd argument of function REPLACE "
-                              "has to be a string or regex scalar");
+                              "has to be a string or regex");
         }
         if (nodes.size() == 3) {
           if (nodes[2]->valueType() != VTScalar
@@ -1664,7 +1697,7 @@ TableExprNodeRep::NodeDataType TableExprFuncNode::checkOperands
                nodes[1]->dataType() != NTInt)  ||
               nodes[1]->valueType() != VTScalar) {
             throw TableInvExpr ("2nd argument of function STRING "
-                                "has to be a scalar string or int value");
+                                "has to be a scalar string or real value");
           }
         }
 	dtypeOper.resize (nodes.size());
@@ -1690,6 +1723,11 @@ TableExprNodeRep::NodeDataType TableExprFuncNode::checkOperands
     case log10FUNC:
     case sqrtFUNC:
     case conjFUNC:
+    case asinFUNC:
+    case acosFUNC:
+    case atanFUNC:
+    case tanFUNC:
+    case tanhFUNC:
 	checkNumOfArg (1, 1, nodes);
 	return checkDT (dtypeOper, NTNumeric, NTDouCom, nodes);
     case squareFUNC:
@@ -1712,13 +1750,6 @@ TableExprNodeRep::NodeDataType TableExprFuncNode::checkOperands
     case imagFUNC:
 	checkNumOfArg (1, 1, nodes);
 	return checkDT (dtypeOper, NTNumeric, NTDouble, nodes);
-    case asinFUNC:
-    case acosFUNC:
-    case atanFUNC:
-    case tanFUNC:
-    case tanhFUNC:
-	checkNumOfArg (1, 1, nodes);
-	return checkDT (dtypeOper, NTReal, NTDouble, nodes);
     case signFUNC:
     case roundFUNC:
     case floorFUNC:
@@ -1745,9 +1776,13 @@ TableExprNodeRep::NodeDataType TableExprFuncNode::checkOperands
     {
 	checkNumOfArg (3, 3, nodes);
 	// Check if tolerance has a Real value.
-	PtrBlock<TableExprNodeRep*> nodeTol(1);
+	vector<TENShPtr> nodeTol(1);
 	nodeTol[0] = nodes[2];
 	checkDT (dtypeOper, NTReal, NTBool, nodeTol);
+	if (nodes[2]->valueType() != VTScalar) {
+	    throw TableInvExpr ("3rd argument of function NEAR and NEARABS "
+				"has to be a scalar");
+	}
 	return checkDT (dtypeOper, NTNumeric, NTBool, nodes);
     }
     case powFUNC:
@@ -1777,16 +1812,17 @@ TableExprNodeRep::NodeDataType TableExprFuncNode::checkOperands
     case iifFUNC:
       {
 	checkNumOfArg (3, 3, nodes);
-	PtrBlock<TableExprNodeRep*> nodeCond(1);
+	vector<TENShPtr> nodeCond(1);
 	nodeCond[0] = nodes[0];
-	PtrBlock<TableExprNodeRep*> nodeArg(2);
+	vector<TENShPtr> nodeArg(2);
 	nodeArg[0] = nodes[1];
 	nodeArg[1] = nodes[2];
 	Block<Int> dtypeTmp;
 	checkDT (dtypeTmp, NTBool, NTBool, nodeCond);
 	dtypeOper.resize(3);
 	dtypeOper[0] = dtypeTmp[0];
-	NodeDataType dt = checkDT (dtypeTmp, NTAny, NTAny, nodeArg);
+        // Do not allow automatic conversion to date/time.
+	NodeDataType dt = checkDT (dtypeTmp, NTAny, NTAny, nodeArg, False);
 	dtypeOper[1] = dtypeTmp[0];
 	dtypeOper[2] = dtypeTmp[1];
 	return dt;
@@ -1795,7 +1831,7 @@ TableExprNodeRep::NodeDataType TableExprFuncNode::checkOperands
 	break;
     }
     // The following functions accept scalars only (or no arguments).
-    for (i=0; i< nodes.nelements(); i++) {
+    for (i=0; i< nodes.size(); i++) {
 	if (nodes[i]->valueType() != VTScalar) {
 	    throw TableInvExpr ("Function nr " + String::toString(fType) +
                                 " has to have a scalar argument");
