@@ -74,16 +74,18 @@ public:
     TableExprFuncNodeArray (TableExprFuncNode::FunctionType,
 			    NodeDataType, ValueType,
 			    const TableExprNodeSet& source,
+                            const vector<TENShPtr>& nodes,
+                            const Block<Int>& dtypeOper,
 			    const TaQLStyle&);
 
     // Destructor
     ~TableExprFuncNodeArray();
 
     // Get the nodes representing an aggregate function.
-    virtual void getAggrNodes (vector<TableExprNodeRep*>& aggr);
+    virtual void getAggrNodes (std::vector<TableExprNodeRep*>& aggr);
 
     // Get the nodes representing a table column.
-    virtual void getColumnNodes (vector<TableExprNodeRep*>& cols);
+    virtual void getColumnNodes (std::vector<TableExprNodeRep*>& cols);
   
     // 'get' Functions to get the desired result of a function
     // <group>
@@ -101,23 +103,17 @@ public:
     const TableExprFuncNode* getChild() const
       { return &node_p; }
 
-    // Link the children to the node and convert the children
-    // to constants if possible. Also convert the node to
-    // constant if possible.
-    static TableExprNodeRep* fillNode (TableExprFuncNodeArray* thisNode,
-				       PtrBlock<TableExprNodeRep*>& nodes,
-				       const Block<Int>& dtypeOper);
-
 protected:
     // Try if the function gives a constant result.
     // If so, set the expression type to Constant.
+    // Get possible constant arguments like axes.
     void tryToConst();
 
     // Some functions to be used by TableExprNodeFuncArray.
     // <group>
-    const PtrBlock<TableExprNodeRep*>& operands() const
+    const std::vector<TENShPtr>& operands() const
         { return node_p.operands(); }
-    PtrBlock<TableExprNodeRep*>& rwOperands()
+    std::vector<TENShPtr>& rwOperands()
         { return node_p.rwOperands(); }
     TableExprFuncNode::FunctionType funcType() const
         { return node_p.funcType(); }
@@ -126,10 +122,6 @@ protected:
     // </group>
 
 private:
-    // Set unit scale factor (needed for sqrt).
-    void setScale (Double scale)
-        { node_p.setScale (scale); }
-
     // Get the collapse axes for the partial functions.
     // It compares the values with the #dim and removes them if too high.
     // axarg gives the argument nr of the axes.
@@ -139,9 +131,12 @@ private:
     // Remove axes exceeding ndim.
     IPosition removeAxes (const IPosition& axes, Int ndim) const;
 
-    // Get the shape for the array function.
+    // Get the shape for the array, boxed and running functions.
+    // If an axis length < 0, the corresponding main shape axis (if present)
+    // is used.
     // axarg gives the argument nr of the shape.
-    const IPosition& getArrayShape (const TableExprId& id, uInt axarg=1);
+    const IPosition& getArrayShape (const TableExprId& id,
+                                    uInt axarg=1);
 
     // Get the transpose order of the array axes.
     IPosition getOrder (const TableExprId& id, Int ndim);
@@ -154,10 +149,19 @@ private:
     // Set the alternate value expandAlt_p for array expand and return it.
     const IPosition& getAlternate (const TableExprId& id);
 
-    // Templated fucntion to resize/expand an array.
+    // Adjust the resize shape by replacing negative axes with the
+    // original axis (if present) or 1.
+    IPosition adjustShape (const IPosition& shape,
+                           const IPosition& origShape) const;
+  
+    // Templated function to resize/expand an array.
     template<typename T>
     MArray<T> TEFResize (const MArray<T>& arr, const TableExprId& id);
 
+    // The angular distance between each pair of the arguments.
+    MArray<Double> angdistx (const MArray<Double>& a1,
+                             const MArray<Double>& a2) const;
+
 
     //# Data members
     TableExprFuncNode node_p;
