@@ -283,9 +283,8 @@ Bool TableExprNodeGEDate::getBool (const TableExprId& id)
 
 
 TableExprNodeINInt::TableExprNodeINInt (const TableExprNodeRep& node,
-                                        Bool doTracing)
-: TableExprNodeBinary (NTBool, node, OtIN),
-  itsDoTracing (doTracing)
+                                        Bool)
+: TableExprNodeBinary (NTBool, node, OtIN)
 {}
 void TableExprNodeINInt::convertConstChild()
 {
@@ -392,7 +391,7 @@ Bool TableExprNodeNOT::getBool (const TableExprId& id)
 void TableExprNodeEQDouble::ranges (Block<TableExprRange>& blrange)
 {
     Double dval = 0;
-    TableExprNodeRep* tsncol = 0;
+    TENShPtr tsncol = 0;
     //# We can store a range if there is a scalar column and constant
     //# (left or right).
     if (lnode_p->operType()  == TableExprNodeRep::OtColumn
@@ -411,7 +410,7 @@ void TableExprNodeEQDouble::ranges (Block<TableExprRange>& blrange)
     //# Now create a range (if possible).
     //# The cast is harmless, since it is surely that object type.
     TableExprNodeRep::createRange (blrange,
-				   dynamic_cast<TableExprNodeColumn*>(tsncol),
+				   dynamic_cast<TableExprNodeColumn*>(tsncol.get()),
 				   dval, dval);
 }
 
@@ -419,7 +418,7 @@ void TableExprNodeGEDouble::ranges (Block<TableExprRange>& blrange)
 {
     Double st = 0;
     Double end = 0;
-    TableExprNodeRep* tsncol = 0;
+    TENShPtr tsncol = 0;
     //# We can store a range if there is a scalar column and constant
     //# (left or right).
     if (lnode_p->operType()  == TableExprNodeRep::OtColumn
@@ -440,7 +439,7 @@ void TableExprNodeGEDouble::ranges (Block<TableExprRange>& blrange)
     //# Now create a range (if possible).
     //# The cast is harmless, since it is surely that object type.
     TableExprNodeRep::createRange (blrange,
-				   dynamic_cast<TableExprNodeColumn*>(tsncol),
+				   dynamic_cast<TableExprNodeColumn*>(tsncol.get()),
 				   st, end);
 }
 
@@ -448,7 +447,7 @@ void TableExprNodeGTDouble::ranges (Block<TableExprRange>& blrange)
 {
     Double st = 0;
     Double end = 0;
-    TableExprNodeRep* tsncol = 0;
+    TENShPtr tsncol = 0;
     //# We can store a range if there is a scalar column and constant
     //# (left or right).
     if (lnode_p->operType()  == TableExprNodeRep::OtColumn
@@ -469,7 +468,7 @@ void TableExprNodeGTDouble::ranges (Block<TableExprRange>& blrange)
     //# Now create a range (if possible).
     //# The cast is harmless, since it is surely that object type.
     TableExprNodeRep::createRange (blrange,
-				   dynamic_cast<TableExprNodeColumn*>(tsncol),
+				   dynamic_cast<TableExprNodeColumn*>(tsncol.get()),
 				   st, end);
 }
 
