@@ -31,9 +31,6 @@
 #include <casacore/tables/TaQL/ExprDerNodeArray.h>
 #include <casacore/tables/TaQL/ExprUnitNode.h>
 #include <casacore/tables/TaQL/ExprRange.h>
-#include <casacore/tables/Tables/TableDesc.h>
-#include <casacore/tables/Tables/TableRecord.h>
-#include <casacore/tables/Tables/ColumnDesc.h>
 #include <casacore/tables/Tables/TableError.h>
 #include <casacore/casa/Containers/Block.h>
 #include <casacore/tables/TaQL/MArray.h>
@@ -48,8 +45,7 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
 TableExprNodeRep::TableExprNodeRep (NodeDataType dtype, ValueType vtype,
 				    OperType optype,
 				    const Table& table)
-: count_p    (0),
-  table_p    (table),
+: table_p    (table),
   dtype_p    (dtype),
   vtype_p    (vtype),
   optype_p   (optype),
@@ -67,8 +63,7 @@ TableExprNodeRep::TableExprNodeRep (NodeDataType dtype, ValueType vtype,
 				    ExprType exprtype,
 				    Int ndim, const IPosition& shape,
 				    const Table& table)
-: count_p    (0),
-  table_p    (table),
+: table_p    (table),
   dtype_p    (dtype),
   vtype_p    (vtype),
   optype_p   (optype),
@@ -79,8 +74,7 @@ TableExprNodeRep::TableExprNodeRep (NodeDataType dtype, ValueType vtype,
 {}
 
 TableExprNodeRep::TableExprNodeRep (const TableExprNodeRep& that)
-: count_p    (0),
-  table_p    (that.table_p),
+ : table_p    (that.table_p),
   dtype_p    (that.dtype_p),
   vtype_p    (that.vtype_p),
   optype_p   (that.optype_p),
@@ -95,15 +89,6 @@ TableExprNodeRep::~TableExprNodeRep ()
 {}
 
 
-void TableExprNodeRep::unlink (TableExprNodeRep* node)
-{
-    if (node != 0) {
-	if (--node->count_p == 0) {
-	    delete node;
-	}
-    }
-}
-
 void TableExprNodeRep::show (ostream& os, uInt indent) const
 {
     for (uInt i=0; i<indent; i++) {
@@ -126,15 +111,13 @@ void TableExprNodeRep::getAggrNodes (vector<TableExprNodeRep*>&)
 void TableExprNodeRep::getColumnNodes (vector<TableExprNodeRep*>&)
 {}
 
-void TableExprNodeRep::checkAggrFuncs (const TableExprNodeRep* node)
+void TableExprNodeRep::checkAggrFuncs()
 {
   vector<TableExprNodeRep*> aggr;
-  if (node) {
-    const_cast<TableExprNodeRep*>(node)->getAggrNodes (aggr);
-    if (! aggr.empty()) {
-      throw TableInvExpr("Invalid use of an aggregate function "
-                         "(only use in SELECT or HAVING clause)");
-    }
+  getAggrNodes (aggr);
+  if (! aggr.empty()) {
+    throw TableInvExpr("Invalid use of an aggregate function "
+                       "(only use in SELECT or HAVING clause)");
   }
 }
 
@@ -170,12 +153,12 @@ void TableExprNodeRep::convertConstChild()
 {}
 
 void TableExprNodeRep::checkTablePtr (Table& table,
-				      const TableExprNodeRep* node)
+				      const TENShPtr& node)
 {
-    if (node != 0) {
-      if (table.isNull()  ||  table.nrow() == 0) {
+    if (node) {
+        if (table.isNull()  ||  table.nrow() == 0) {
 	    table = node->table();
-	}else{
+	} else {
         if (!(node->table().isNull()  ||  node->table().nrow() == 0)
             &&  node->table().nrow() != table.nrow()) {
 		throw (TableInvExpr
@@ -185,7 +168,7 @@ void TableExprNodeRep::checkTablePtr (Table& table,
     }
 }
 void TableExprNodeRep::fillExprType (ExprType& type,
-				     const TableExprNodeRep* node)
+				     const TENShPtr& node)
 {
     if (node != 0  &&  !node->isConstant()) {
 	type = Variable;
@@ -216,7 +199,7 @@ void TableExprNodeRep::createRange (Block<TableExprRange>& blrange,
 {
     if (tsn == 0) {
 	blrange.resize (0, True);
-    }else{
+    } else {
 	blrange.resize (1, True);
 	blrange[0] = TableExprRange (tsn->getColumn(), st, end);
     }
@@ -224,7 +207,7 @@ void TableExprNodeRep::createRange (Block<TableExprRange>& blrange,
 
 const IPosition& TableExprNodeRep::shape (const TableExprId& id)
 {
-    if (ndim_p == 0  ||  shape_p.nelements() != 0) {
+    if (ndim_p == 0  ||  shape_p.size() != 0) {
 	return shape_p;
     }
     return getShape (id);
@@ -534,15 +517,15 @@ Array<String>   TableExprNodeRep::getColumnString
 // It is a optimization to remove an OR or AND when one branch is constant.
 // It should be done in TableExprNodeBinary.
 #if defined(TABLEXPRNODEREP_NEVER_TRUE)
-TableExprNodeRep* TableExprNodeBinary::shortcutOrAnd ()
+TENShPtr TableExprNodeBinary::shortcutOrAnd ()
 {
     if (thisNode->operType() != OtOR  &&  thisNode->operType() != OtAND) {
 	return this;
     }
     // Determine if and which node is a constant.
     // Exit if no constant.
-    TableExprNodeRep** constNode = &lnode_p;
-    TableExprNodeRep** otherNode = &rnode_p;
+    TENShPtr* constNode = &lnode_p;
+    TENShPtr* otherNode = &rnode_p;
     if (! lnode_p->isConstant()) {
 	if (! rnode_p->isConstant()) {
 	    return this;
@@ -561,119 +544,91 @@ TableExprNodeRep* TableExprNodeBinary::shortcutOrAnd ()
     // A false results in a constant false when the other operand is a scalar.
     // So in that case the constant is the result.
     // For OR the same can be done.
-	    (**otherNode).count_p++;
-	    delete thisNode;
-	    (**otherNode).count_p--;
     if (thisNode->operType() == OtAND) {
 	if (value) {
 	    return *otherNode;
-	}else{
+	} else {
 	    if ((**otherNode).valueType() != VTScalar) {
 		return *constNode;
 	    }
 	}
-    }else{
+    } else {
 	if (value) {
 	    if ((**otherNode).valueType() != VTScalar) {
 		return this;
 	    }
-	}else{
+	} else {
 	    return *otherNode;
 	}
     }
     return *constNode;
-
-    // In the calling routine something like the following has to be done.
-    TableExprNodeRep* node = shortcutAndOr();
-    if (node != thisNode) {
-	node->count_p++; // prevent child from being deleted by delete thisNode
-	delete thisNode;
-	node->count_p--;
-    }
 }
 #endif
 
-TableExprNodeRep* TableExprNodeRep::convertNode (TableExprNodeRep* thisNode,
-						 Bool convertConstType)
+TENShPtr TableExprNodeRep::replaceConstNode (const TENShPtr& node)
 {
-    // If the expression is not constant, try to convert the type
-    // of a constant child to the other child's type.
-    if (! thisNode->isConstant()) {
-	if (convertConstType) {
-	    thisNode->convertConstChild();
-	}
-	return thisNode;
+  // If the expression is not constant, try to convert the type
+  // of a constant child to the other child's type.
+  if (! node->isConstant()) {
+    return node;
+  }
+  // Evaluate the constant subexpression and replace the node.
+  TENShPtr newNode;
+  if (node->valueType() == VTScalar) {
+    switch (node->dataType()) {
+    case NTBool:
+      newNode = new TableExprNodeConstBool (node->getBool (0));
+      break;
+    case NTInt:
+      newNode = new TableExprNodeConstInt (node->getInt (0));
+      break;
+    case NTDouble:
+      newNode = new TableExprNodeConstDouble (node->getDouble (0));
+      break;
+    case NTComplex:
+      newNode = new TableExprNodeConstDComplex (node->getDComplex(0));
+      break;
+    case NTString:
+      newNode = new TableExprNodeConstString (node->getString (0));
+      break;
+    case NTRegex:
+      newNode = new TableExprNodeConstRegex (node->getRegex (0));
+      break;
+    case NTDate:
+      newNode = new TableExprNodeConstDate (node->getDate (0));
+      break;
+    default:
+      TableExprNode::throwInvDT ("in replaceConstNode"); // should never occur
     }
-    // Evaluate the constant subexpression and replace the node.
-    TableExprNodeRep* newNode = 0;
-    if (thisNode->valueType() == VTScalar) {
-	switch (thisNode->dataType()) {
-	case NTBool:
-	    newNode = new TableExprNodeConstBool (thisNode->getBool (0));
-	    break;
-	case NTInt:
-	    newNode = new TableExprNodeConstInt (thisNode->getInt (0));
-	    break;
-	case NTDouble:
-	    newNode = new TableExprNodeConstDouble (thisNode->getDouble (0));
-	    break;
-	case NTComplex:
-	    newNode = new TableExprNodeConstDComplex (thisNode->getDComplex(0));
-	    break;
-	case NTString:
-	    newNode = new TableExprNodeConstString (thisNode->getString (0));
-	    break;
-	case NTRegex:
-	    newNode = new TableExprNodeConstRegex (thisNode->getRegex (0));
-	    break;
-	case NTDate:
-	    newNode = new TableExprNodeConstDate (thisNode->getDate (0));
-	    break;
-	default:
-	    TableExprNode::throwInvDT ("in convertNode"); // should never occur
-	}
-    }else{
-	switch (thisNode->dataType()) {
-	case NTBool:
-	    newNode = new TableExprNodeArrayConstBool
-                                         (thisNode->getArrayBool (0));
-	    break;
-	case NTInt:
-	    newNode = new TableExprNodeArrayConstInt
-                                         (thisNode->getArrayInt (0));
-	    break;
-	case NTDouble:
-	    newNode = new TableExprNodeArrayConstDouble
-                                         (thisNode->getArrayDouble (0));
-	    break;
-	case NTComplex:
-	    newNode = new TableExprNodeArrayConstDComplex
-                                         (thisNode->getArrayDComplex (0));
-	    break;
-	case NTString:
-	    newNode = new TableExprNodeArrayConstString
-                                         (thisNode->getArrayString (0));
-	    break;
-	case NTDate:
-	    newNode = new TableExprNodeArrayConstDate
-                                         (thisNode->getArrayDate (0));
-	    break;
-	default:
-	    TableExprNode::throwInvDT ("in convertNode"); // should never occur
-	}
+  } else {
+    switch (node->dataType()) {
+    case NTBool:
+      newNode = new TableExprNodeArrayConstBool(node->getArrayBool (0));
+      break;
+    case NTInt:
+      newNode = new TableExprNodeArrayConstInt(node->getArrayInt (0));
+      break;
+    case NTDouble:
+      newNode = new TableExprNodeArrayConstDouble(node->getArrayDouble (0));
+      break;
+    case NTComplex:
+      newNode = new TableExprNodeArrayConstDComplex(node->getArrayDComplex (0));
+      break;
+    case NTString:
+      newNode = new TableExprNodeArrayConstString(node->getArrayString (0));
+      break;
+    case NTDate:
+      newNode = new TableExprNodeArrayConstDate(node->getArrayDate (0));
+      break;
+    default:
+      TableExprNode::throwInvDT ("in replaceConstNode"); // should never occur
     }
-    newNode->setUnit (thisNode->unit());
-    delete thisNode;
-    return newNode;
+  }
+  newNode->setUnit (node->unit());
+  return newNode;
 }    
 
 
-TableExprNodeRep* TableExprNodeRep::getRep (TableExprNode& node)
-{
-    return node.getRep();
-}
-
-
 
 
 // ------------------------------
@@ -688,7 +643,7 @@ TableExprNodeBinary::TableExprNodeBinary (NodeDataType tp,
   lnode_p          (0),
   rnode_p          (0)
 {}
-    
+
 TableExprNodeBinary::TableExprNodeBinary (NodeDataType tp,
 					  const TableExprNodeRep& that,
 					  OperType oper)
@@ -699,12 +654,9 @@ TableExprNodeBinary::TableExprNodeBinary (NodeDataType tp,
     dtype_p  = tp;
     optype_p = oper;
 }
-    
+
 TableExprNodeBinary::~TableExprNodeBinary()
-{
-    unlink (lnode_p);
-    unlink (rnode_p);
-}
+{}
 
 void TableExprNodeBinary::show (ostream& os, uInt indent) const
 {
@@ -813,12 +765,12 @@ TableExprNodeRep::NodeDataType TableExprNodeBinary::getDT
     return NTComplex; // compiler satisfaction
 }
 
-TableExprNodeRep TableExprNodeBinary::getTypes (const TableExprNodeRep& left,
-						const TableExprNodeRep& right,
-						OperType opt)
+TableExprNodeRep TableExprNodeBinary::getCommonTypes (const TENShPtr& left,
+                                                      const TENShPtr& right,
+                                                      OperType opt)
 {
-    ValueType leftVtype = left.valueType();
-    ValueType rightVtype = right.valueType();
+    ValueType leftVtype = left->valueType();
+    ValueType rightVtype = right->valueType();
     // Check that the value type is VTScalar and/or VTArray.
     if ((leftVtype  != VTArray  &&  leftVtype  != VTScalar)
     ||  (rightVtype != VTArray  &&  rightVtype != VTScalar)) {
@@ -829,11 +781,11 @@ TableExprNodeRep TableExprNodeBinary::getTypes (const TableExprNodeRep& left,
     ValueType vtype;
     if (leftVtype == VTArray  ||  rightVtype == VTArray) {
 	vtype = VTArray;
-    }else{
+    } else {
 	vtype = VTScalar;
     }
-    NodeDataType leftDtype = left.dataType();
-    NodeDataType rightDtype = right.dataType();
+    NodeDataType leftDtype = left->dataType();
+    NodeDataType rightDtype = right->dataType();
     NodeDataType dtype = getDT (leftDtype, rightDtype, opt);
     ArgType atype = ArrArr;
     // Set the argument type in case arrays are involved.
@@ -849,12 +801,12 @@ TableExprNodeRep TableExprNodeBinary::getTypes (const TableExprNodeRep& left,
     Int ndim = -1;
     if (leftVtype == VTScalar  &&  rightVtype == VTScalar) {
 	ndim = 0;
-    }else{
+    } else {
 	// Check if the 2 operands have matching dimensionality and shape.
 	// This can only be done if they are fixed.
 	// Also determine the resulting dimensionality and shape.
-	Int leftNdim = left.ndim();
-	Int rightNdim = right.ndim();
+	Int leftNdim = left->ndim();
+	Int rightNdim = right->ndim();
 	if (leftNdim > 0) {
 	    ndim = leftNdim;
 	    if (rightNdim > 0  &&  leftNdim != rightNdim) {
@@ -863,10 +815,10 @@ TableExprNodeRep TableExprNodeBinary::getTypes (const TableExprNodeRep& left,
 	} else if (rightNdim > 0) {
 	    ndim = rightNdim;
 	}
-	IPosition leftShape = left.shape();
-	IPosition rightShape = right.shape();
-	leftNdim = leftShape.nelements();
-	rightNdim = rightShape.nelements();
+	IPosition leftShape = left->shape();
+	IPosition rightShape = right->shape();
+	leftNdim = leftShape.size();
+	rightNdim = rightShape.size();
 	if (leftNdim > 0) {
 	    shape = leftShape;
 	    if (rightNdim > 0  &&  !leftShape.isEqual (rightShape)) {
@@ -878,92 +830,75 @@ TableExprNodeRep TableExprNodeBinary::getTypes (const TableExprNodeRep& left,
     }
     // The result is constant when both operands are constant.
     ExprType extype = Variable;
-    if (left.isConstant()  &&  right.isConstant()) {
+    if (left->isConstant()  &&  right->isConstant()) {
 	extype = Constant;
     }
     // Determine from which table the expression is coming
     // and whether the tables match.
-    Table table = left.table();
-    checkTablePtr (table, &right);
+    Table table = left->table();
+    checkTablePtr (table, right);
     return TableExprNodeRep (dtype, vtype, opt, atype, extype, ndim, shape,
 			     table);
 }
 
-// Fill the child pointers of a node.
-// Also reduce the tree if possible by combining constants.
-// When only one of the nodes is a constant, convert its type if
-// it does not match the other one.
-TableExprNodeRep* TableExprNodeBinary::fillNode (TableExprNodeBinary* thisNode,
-						 TableExprNodeRep* left,
-						 TableExprNodeRep* right,
-						 Bool convertConstType,
-                                                 Bool adaptDataType)
+void TableExprNodeBinary::setChildren (const TENShPtr& left,
+                                       const TENShPtr& right,
+                                       Bool adapt)
 {
-    // Fill the children and link to them.
-    // If needed, change the children to get matching data types.
-    thisNode->lnode_p = left->link();
-    if (right != 0) {
-      thisNode->rnode_p = right->link();
-      if (adaptDataType) {
-        // Adapt data types as needed.
-
-	// NTRegex will always be placed in the right node 
-	if (left->dataType() == NTRegex) {
-	    thisNode->lnode_p = right;
-	    thisNode->rnode_p = left;
-	}
-
-	// If expression with date and double or string, convert to date
-	if (left->dataType() == NTDate) {
-            if (right->dataType() == NTString) {
-                TableExprNode dNode = datetime (right);
-	        unlink (right);
-	        thisNode->rnode_p = getRep(dNode)->link();
-            } else if (right->dataType() == NTDouble  ||
-                       right->dataType() == NTInt) {
-                TableExprNode dNode = mjdtodate (right);
-	        unlink (right);
-	        thisNode->rnode_p = getRep(dNode)->link();
-            }
+  lnode_p = left;
+  rnode_p = right;
+  if (right) {
+    // NTRegex will always be placed in the right node.
+    if (left->dataType() == NTRegex) {
+      lnode_p = right;
+      rnode_p = left;
+    } else {
+      // If expression with date and double or string, convert to date.
+      if (left->dataType() == NTDate) {
+        if (right->dataType() == NTString) {
+          TableExprNode dNode = datetime (right);
+          rnode_p = dNode.getRep();
+        } else if (right->isReal()) {
+          TableExprNode dNode = mjdtodate (right);
+          rnode_p = dNode.getRep();
         }
-	if (right->dataType() == NTDate) {
-            if (left->dataType() == NTString) {
-                TableExprNode dNode = datetime (left);
-                unlink (left);
-                thisNode->lnode_p = getRep(dNode)->link();
-            } else if (left->dataType() == NTDouble  ||
-                       left->dataType() == NTInt) {
-                TableExprNode dNode = mjdtodate (left);
-                unlink (left);
-                thisNode->lnode_p = getRep(dNode)->link();
-            }
+      }
+      if (right->dataType() == NTDate) {
+        if (left->dataType() == NTString) {
+          TableExprNode dNode = datetime (left);
+          lnode_p = dNode.getRep();
+        } else if (left->isReal()) {
+          TableExprNode dNode = mjdtodate (left);
+          lnode_p = dNode.getRep();
         }
-        // date-date results in double, so convert if needed.
-        if (thisNode->dataType() == NTDouble) {
-            if (left->dataType() == NTDate) {
-                TableExprNode dNode = mjd (left);
-                unlink (left);
-                thisNode->lnode_p = getRep(dNode)->link();
-            }
-            if (right->dataType() == NTDate) {
-                TableExprNode dNode = mjd (right);
-                unlink (right);
-                thisNode->rnode_p = getRep(dNode)->link();
-            }
+      }
+      // date-date results in double, so convert if needed.
+      if (dataType() == NTDouble) {
+        if (left->dataType() == NTDate) {
+          TableExprNode dNode = mjd (left);
+          lnode_p = dNode.getRep();
+        }
+        if (right->dataType() == NTDate) {
+          TableExprNode dNode = mjd (right);
+          rnode_p = dNode.getRep();
         }
       }
     }
+  }
+  if (adapt) {
     // Check and adapt units.
-    thisNode->handleUnits();
-    return convertNode (thisNode, convertConstType);
+    handleUnits();
+    // Adapt data types as needed.
+    adaptDataTypes();
+  }
 }
 
-const Unit& TableExprNodeBinary::makeEqualUnits (TableExprNodeRep* left,
-						 TableExprNodeRep*& right)
+const Unit& TableExprNodeBinary::makeEqualUnits (const TENShPtr& left,
+						 TENShPtr& right)
 {
     // The first real unit is chosen as the result unit.
     const Unit* unit = &(left->unit());
-    if (right != 0) {
+    if (right) {
         if (unit->empty()) {
 	    unit = &(right->unit());
 	} else if (! right->unit().empty()) {
@@ -976,25 +911,25 @@ const Unit& TableExprNodeBinary::makeEqualUnits (TableExprNodeRep* left,
 void TableExprNodeBinary::handleUnits()
 {
     const Unit& resUnit = makeEqualUnits (lnode_p, rnode_p);
-    // A comparison has no units, so only set if not bool.
+    // A comparison has no units, so only set result unit if not bool.
     if (dataType() != NTBool) {
       setUnit (resUnit);
     }
 }
 
-void TableExprNodeBinary::convertConstChild()
+void TableExprNodeBinary::adaptDataTypes()
 {
     // Convert data type of a constant 
     // from Double to DComplex if:
     //   - there are 2 nodes
     //   - data types are not equal
     //   - conversion from Int or Double can be done
-    if (rnode_p == 0  ||  lnode_p->dataType() == rnode_p->dataType()) {
+    if (!rnode_p  ||  lnode_p->dataType() == rnode_p->dataType()) {
 	return;
     }
     // Determine if and which node is a constant.
-    TableExprNodeRep** constNode = &lnode_p;
-    TableExprNodeRep** otherNode = &rnode_p;
+    TENShPtr* constNode = &lnode_p;
+    TENShPtr* otherNode = &rnode_p;
     if (! lnode_p->isConstant()) {
 	if (! rnode_p->isConstant()) {
 	    return;
@@ -1003,20 +938,20 @@ void TableExprNodeBinary::convertConstChild()
 	otherNode = &lnode_p;
     }
     // Only scalars and arrays can be converted.
-    ValueType vtype = (**constNode).valueType();
+    ValueType vtype = (*constNode)->valueType();
     if (vtype != VTScalar  &&  vtype != VTArray) {
 	return;
     }
     // The only possible conversion is from Int or Double to Double or DComplex.
     NodeDataType newType = NTDouble;
-    if ((**otherNode).dataType() == NTDouble) {
-        if ((**constNode).dataType() != NTInt) {
+    if ((*otherNode)->dataType() == NTDouble) {
+        if ((*constNode)->dataType() != NTInt) {
             return;
         }
-    } else if ((**otherNode).dataType() == NTComplex) {
+    } else if ((*otherNode)->dataType() == NTComplex) {
         newType = NTComplex;
-        if (((**constNode).dataType() != NTInt)
-        &&  ((**constNode).dataType() != NTDouble)) {
+        if (((*constNode)->dataType() != NTInt)
+        &&  ((*constNode)->dataType() != NTDouble)) {
             return;
         }
     } else {
@@ -1026,25 +961,24 @@ void TableExprNodeBinary::convertConstChild()
 #if defined(AIPS_TRACE)
     cout << "constant converted" << endl;
 #endif
-    TableExprNodeRep* newNode;
+    TENShPtr newNode;
     if (vtype == VTScalar) {
       if (newType == NTDouble) {
-	newNode = new TableExprNodeConstDouble ((**constNode).getDouble(0));
+	newNode = new TableExprNodeConstDouble ((*constNode)->getDouble(0));
       } else {
-	newNode = new TableExprNodeConstDComplex ((**constNode).getDouble(0));
+	newNode = new TableExprNodeConstDComplex ((*constNode)->getDouble(0));
       }
-    }else{
+    } else {
       if (newType == NTDouble) {
 	newNode = new TableExprNodeArrayConstDouble
-	                                    ((**constNode).getArrayDouble(0));
+	                                    ((*constNode)->getArrayDouble(0));
       } else {
 	newNode = new TableExprNodeArrayConstDComplex
-	                                    ((**constNode).getArrayDouble(0));
+	                                    ((*constNode)->getArrayDouble(0));
       }
     }
-    newNode->setUnit ((**constNode).unit());
-    unlink (*constNode);
-    *constNode = newNode->link();
+    newNode->setUnit ((*constNode)->unit());
+    *constNode = newNode;
 }
 
 
@@ -1065,16 +999,12 @@ TableExprNodeMulti::TableExprNodeMulti (NodeDataType tp, ValueType vtype,
 }
 
 TableExprNodeMulti::~TableExprNodeMulti()
-{
-    for (uInt i=0; i<operands_p.nelements(); i++) {
-	unlink (operands_p[i]);
-    }
-}
+{}
 
 void TableExprNodeMulti::show (ostream& os, uInt indent) const
 {
     TableExprNodeRep::show (os, indent);
-    for (uInt j=0; j<operands_p.nelements(); j++) {
+    for (uInt j=0; j<operands_p.size(); j++) {
 	if (operands_p[j] != 0) {
 	    operands_p[j]->show (os, indent+2);
 	}
@@ -1083,7 +1013,7 @@ void TableExprNodeMulti::show (ostream& os, uInt indent) const
 
 void TableExprNodeMulti::getAggrNodes (vector<TableExprNodeRep*>& aggr)
 {
-    for (uInt j=0; j<operands_p.nelements(); j++) {
+    for (uInt j=0; j<operands_p.size(); j++) {
 	if (operands_p[j] != 0) {
             operands_p[j]->getAggrNodes (aggr);
 	}
@@ -1092,7 +1022,7 @@ void TableExprNodeMulti::getAggrNodes (vector<TableExprNodeRep*>& aggr)
 
 void TableExprNodeMulti::getColumnNodes (vector<TableExprNodeRep*>& cols)
 {
-    for (uInt j=0; j<operands_p.nelements(); j++) {
+    for (uInt j=0; j<operands_p.size(); j++) {
 	if (operands_p[j] != 0) {
             operands_p[j]->getColumnNodes (cols);
 	}
@@ -1111,25 +1041,25 @@ Bool TableExprNodeRep::isLazyAggregate() const
 
 
 
-uInt TableExprNodeMulti::checkNumOfArg
-                                    (uInt low, uInt high,
-				     const PtrBlock<TableExprNodeRep*>& nodes)
+uInt TableExprNodeMulti::checkNumOfArg (uInt low, uInt high,
+                                        const vector<TENShPtr>& nodes)
 {
-    if (nodes.nelements() < low) {
+    if (nodes.size() < low) {
 	throw (TableInvExpr("too few function arguments"));
-    } else if (nodes.nelements() > high) {
+    } else if (nodes.size() > high) {
 	throw (TableInvExpr("too many function arguments"));
     }
-    return nodes.nelements();
+    return nodes.size();
 }
 
 TableExprNodeRep::NodeDataType TableExprNodeMulti::checkDT
 				    (Block<Int>& dtypeOper,
 				     NodeDataType dtIn,
 				     NodeDataType dtOut,
-				     const PtrBlock<TableExprNodeRep*>& nodes)
+				     const vector<TENShPtr>& nodes,
+                                     Bool dateConv)
 {
-    uInt nelem = nodes.nelements();
+    uInt nelem = nodes.size();
     dtypeOper.resize (nelem);
     dtypeOper.set (dtIn);
     // NTAny means that it can be any type.
@@ -1179,11 +1109,12 @@ TableExprNodeRep::NodeDataType TableExprNodeMulti::checkDT
     } else {
 	// Data types of the nodes must match dtIn
 	for (i=0; i<nelem; i++) {
-	    // Double or String to Date conversion is possible.
+	    // Double or String to Date conversion can be possible.
 	    if (nodes[i]->dataType() != dtIn) {
-                if (dtIn == NTDate) {
+                if (dateConv  &&  dtIn == NTDate) {
                     if (nodes[i]->dataType() != NTString  &&
-                        nodes[i]->dataType() != NTDouble) {
+                        nodes[i]->dataType() != NTDouble  &&
+                        nodes[i]->dataType() != NTInt) {
                       TableExprNode::throwInvDT("function argument is not "
                                                 "date, string or real");
                     }
