@@ -32,6 +32,7 @@
 #include <casacore/casa/aips.h>
 #include <casacore/tables/TaQL/TaQLNodeRep.h>
 #include <casacore/tables/TaQL/TaQLStyle.h>
+#include <casacore/casa/Utilities/CountedPtr.h>
 #include <casacore/casa/OS/Mutex.h>
 #include <vector>
 #include <iostream>
@@ -83,23 +84,22 @@ class TaQLNode
 public:
   // Default constructor.
   TaQLNode()
-    : itsRep(0) {}
+    {}
 
   // Construct for given letter. It takes over the pointer.
   TaQLNode (TaQLNodeRep* rep)
-    { itsRep = TaQLNodeRep::link (rep); }
+    { itsRep = rep; }
 
   // Copy constructor (reference semantics).
   TaQLNode (const TaQLNode& that)
-    { itsRep = TaQLNodeRep::link (that.itsRep); }
+    { itsRep = that.itsRep; }
 
   // Assignment (reference semantics).
   TaQLNode& operator= (const TaQLNode& that)
     { if (this != &that) {
-        TaQLNodeRep::unlink (itsRep);
-	itsRep = TaQLNodeRep::link (that.itsRep);
+	itsRep = that.itsRep;
       }
-    return *this;
+      return *this;
     }
 
   // Get the TaQL style.
@@ -108,7 +108,7 @@ public:
 
   // Destructor deletes the letter if no more references.
   ~TaQLNode()
-    { TaQLNodeRep::unlink (itsRep); }
+    {}
 
   // Parse a TaQL command and return the result.
   // An exception is thrown in case of parse errors.
@@ -124,7 +124,7 @@ public:
 
   // Get read access to the letter.
   const TaQLNodeRep* getRep() const
-    { return itsRep; }
+    { return itsRep.get(); }
 
   // Let the visitor visit the node.
   // If no node, return an empty result.
@@ -142,9 +142,12 @@ public:
   // </group>
 
 protected:
-  TaQLNodeRep* itsRep;
+  CountedPtr<TaQLNodeRep> itsRep;
+
 private:
+  // Delete all nodes that were created by the parser.
   static void clearNodesCreated();
+
 public:
   // Helper functions for save/restore of tree.
   // <group>
