@@ -48,19 +48,15 @@ namespace casacore {
   {}
 
   UDFBase::~UDFBase()
-  {
-    for (uInt i=0; i<itsOperands.size(); ++i) {
-      TableExprNodeRep::unlink (itsOperands[i]);
-    }
-  }
+  {}
 
-  void UDFBase::init (const PtrBlock<TableExprNodeRep*>& operands,
+  void UDFBase::init (const vector<TENShPtr>& operands,
                       const Table& table, const TaQLStyle& style)
   {
     // Link to the operands.
     itsOperands.resize (operands.size());
     for (uInt i=0; i<operands.size(); ++i) {
-      itsOperands[i] = operands[i]->link();
+      itsOperands[i] = operands[i];
     }
     setup (table, style);
     if (itsDataType == TableExprNodeRep::NTAny) {
@@ -113,6 +109,11 @@ namespace casacore {
     itsUnit = unit;
   }
 
+  void UDFBase::setAttributes (const Record& attributes)
+  {
+    itsAttributes = attributes;
+  }
+
   void UDFBase::setConstant (Bool isConstant)
   {
     itsIsConstant = isConstant;
@@ -166,6 +167,7 @@ namespace casacore {
   {
     String fname(name);
     fname.downcase();
+
     ScopedMutexLock lock(theirMutex);
     map<String,MakeUDFObject*>::iterator iter = theirRegistry.find (fname);
     if (iter == theirRegistry.end()) {
@@ -183,10 +185,14 @@ namespace casacore {
   {
     String fname(name);
     fname.downcase();
-    // Try to find the function.
-    map<String,MakeUDFObject*>::iterator iter = theirRegistry.find (fname);
-    if (iter != theirRegistry.end()) {
-      return iter->second (fname);
+    map<String,MakeUDFObject*>::iterator iter;
+    {
+      ScopedMutexLock lock(theirMutex);
+      // Try to find the function.
+      iter = theirRegistry.find (fname);
+      if (iter != theirRegistry.end()) {
+        return iter->second (fname);
+      }
     }
     String sfname(fname);
     // Split name in library and function name.
@@ -198,6 +204,7 @@ namespace casacore {
       libname = fname.substr(0,j);
       libname = style.findSynonym (libname);
       fname   = libname + fname.substr(j);
+
       ScopedMutexLock lock(theirMutex);
       // See if the library is already loaded.
       iter = theirRegistry.find (libname);
@@ -228,8 +235,11 @@ namespace casacore {
       unk = " (=" + fname + ')';
     }
     throw TableInvExpr ("TaQL function " + sfname + unk +
-                        " is unknown\n"
-                        "  Check (DY)LD_LIBRARY_PATH matches the"
+                        " is unknown" + 
+                        "\n  Library " + libname + " was successfully loaded; "
+                        "taql 'show func " + libname + "' shows its functions"
+                        "\n  Maybe check if (DY)LD_LIBRARY_PATH and "
+                        "CASACORE_LDPATH match the"
                         " libraries used during the build of " + libname);
   }
 
