@@ -561,8 +561,8 @@ public:
   Record getProperties (const String& name, Bool byColumn);
 
   // Set the properties of a data manager given by column or data manager name.
-  void setProperties (const String& name, Bool byColumn,
-                      const Record& properties);
+  void setProperties (const String& name, const Record& properties,
+                      Bool byColumn);
 
   // Get the table description of the table.
   // It returns a record containing the description.
@@ -738,6 +738,9 @@ private:
 		      Int64 rownr, Int64 nrow, Int64 incr,
 		      const String& caller);
 
+  // Make an empty array (with 1 axis) of the correct datatype.
+  ValueHolder makeEmptyArray (DataType dtype);
+
   // Get values from the column.
   // Nrow<0 means till the end of the column.
   ValueHolder getValueFromTable (const String& colName, 
